{"objectClasses"=>
  ["( 2.5.20.1 NAME 'subschema' AUXILIARY MAY ( ditstructurerules $ nameforms $ ditcontentrules $ objectclasses $ attributetypes $ matchingrules $ matchingruleuse )  )",
   "( 2.5.6.0 NAME 'top' ABSTRACT MUST objectclass  )",
   "( 2.5.6.1 NAME 'alias' SUP top  STRUCTURAL MUST aliasedobjectname  )",
   "( 2.5.6.2 NAME 'country' SUP top  STRUCTURAL MUST c  MAY ( enhancedsearchguide $ description )  )",
   "( 2.5.6.3 NAME 'locality' SUP top  STRUCTURAL MAY ( street $ seealso $ enhancedsearchguide $ st $ l $ description )  )",
   "( 2.5.6.4 NAME 'organization' SUP top  STRUCTURAL MUST o  MAY ( userpassword $ enhancedsearchguide $ seealso $ businesscategory $ x121address $ registeredaddress $ destinationindicator $ preferreddeliverymethod $ telexnumber $ teletexterminalidentifier $ telephonenumber $ internationalisdnnumber $ facsimiletelephonenumber $ street $ postofficebox $ postalcode $ postaladdress $ physicaldeliveryofficename $ st $ l $ description )  )",
   "( 2.5.6.5 NAME 'organizationalunit' SUP top  STRUCTURAL MUST ou  MAY ( userpassword $ enhancedsearchguide $ seealso $ businesscategory $ x121address $ registeredaddress $ destinationindicator $ preferreddeliverymethod $ telexnumber $ teletexterminalidentifier $ telephonenumber $ internationalisdnnumber $ facsimiletelephonenumber $ street $ postofficebox $ postalcode $ postaladdress $ physicaldeliveryofficename $ st $ l $ description )  )",
   "( 2.5.6.6 NAME 'person' SUP top  STRUCTURAL MUST ( sn $ cn )  MAY ( userpassword $ telephonenumber $ seealso $ description )  )",
   "( 2.5.6.7 NAME 'organizationalperson' SUP person  STRUCTURAL MAY ( title $ x121address $ registeredaddress $ destinationindicator $ preferreddeliverymethod $ telexnumber $ teletexterminalidentifier $ telephonenumber $ internationalisdnnumber $ facsimiletelephonenumber $ street $ postofficebox $ postalcode $ postaladdress $ physicaldeliveryofficename $ ou $ st $ l )  )",
   "( 2.5.6.8 NAME 'organizationalrole' SUP top  STRUCTURAL MUST cn  MAY ( x121address $ registeredaddress $ destinationindicator $ preferreddeliverymethod $ telexnumber $ teletexterminalidentifier $ telephonenumber $ internationalisdnnumber $ facsimiletelephonenumber $ seealso $ roleoccupant $ street $ postofficebox $ postalcode $ postaladdress $ physicaldeliveryofficename $ ou $ st $ l $ description )  )",
   "( 2.5.6.9 NAME 'groupofnames' SUP top  STRUCTURAL MUST cn  MAY ( member $ businesscategory $ seealso $ owner $ ou $ o $ description )  )",
   "( 2.5.6.11 NAME 'applicationprocess' SUP top  STRUCTURAL MUST cn  MAY ( seealso $ ou $ l $ description )  )",
   "( 2.5.6.12 NAME 'applicationentity' SUP top  STRUCTURAL MUST ( presentationaddress $ cn )  MAY ( supportedapplicationcontext $ seealso $ ou $ o $ l $ description )  )",
   "( 2.5.6.13 NAME 'dsa' SUP applicationentity  STRUCTURAL MAY knowledgeinformation  )",
   "( 2.5.6.14 NAME 'device' SUP top  STRUCTURAL MUST cn  MAY ( serialnumber $ seealso $ owner $ ou $ o $ l $ description )  )",
   "( 2.5.6.15 NAME 'strongauthenticationuser' SUP top  AUXILIARY MUST usercertificate  )",
   "( 2.5.6.16 NAME 'certificationauthority' SUP top  AUXILIARY MUST ( authorityrevocationlist $ certificaterevocationlist $ cacertificate )  MAY crosscertificatepair  )",
   "( 2.5.6.17 NAME 'groupofuniquenames' SUP top  STRUCTURAL MUST ( uniquemember $ cn )  MAY ( businesscategory $ seealso $ owner $ ou $ o $ description )  )",
   "( 2.5.6.18 NAME 'usersecurityinformation' SUP top  AUXILIARY MAY supportedalgorithms  )",
   "( 2.5.6.16.2 NAME 'certificationauthority-v2' SUP certificationauthority  AUXILIARY MAY deltarevocationlist  )",
   "( 2.5.6.19 NAME 'crldistributionpoint' SUP top  STRUCTURAL MUST cn  MAY ( certificaterevocationlist $ authorityrevocationlist $ deltarevocationlist )  )",
   "( 2.5.6.20 NAME 'dmd' SUP top  STRUCTURAL MUST dmdname  MAY ( userpassword $ enhancedsearchguide $ seealso $ businesscategory $ x121address $ registeredaddress $ destinationindicator $ preferreddeliverymethod $ telexnumber $ teletexterminalidentifier $ telephonenumber $ internationalisdnnumber $ facsimiletelephonenumber $ street $ postofficebox $ postalcode $ postaladdress $ physicaldeliveryofficename $ st $ l $ description )  )",
   "( 1.3.6.1.4.1.1466.101.120.111 NAME 'extensibleobject' SUP top  AUXILIARY )",
   "( 0.9.2342.19200300.100.4.13 NAME 'domain' SUP top  STRUCTURAL MUST dc  MAY ( userpassword $ enhancedsearchguide $ seealso $ businesscategory $ x121address $ registeredaddress $ destinationindicator $ preferreddeliverymethod $ telexnumber $ teletexterminalidentifier $ telephonenumber $ internationalisdnnumber $ facsimiletelephonenumber $ street $ postofficebox $ postalcode $ postaladdress $ physicaldeliveryofficename $ st $ l $ description $ o )  )",
   "( 1.3.6.1.4.1.1466.344 NAME 'dcobject' SUP top  AUXILIARY MUST dc  )",
   "( 2.16.840.1.113730.3.2.2 NAME 'inetorgperson' SUP organizationalperson  STRUCTURAL MAY ( audio $ businesscategory $ carlicense $ departmentnumber $ displayname $ employeenumber $ employeetype $ givenname $ homephone $ homepostaladdress $ initials $ jpegphoto $ labeleduri $ mail $ manager $ mobile $ o $ pager $ photo $ roomnumber $ secretary $ uid $ usercertificate $ x500uniqueidentifier $ preferredlanguage $ usersmimecertificate $ userpkcs12 )  )",
   "( 2.16.840.1.113730.3.2.6 NAME 'referral' SUP top  STRUCTURAL MAY ref  )",
   "( 2.16.840.1.113719.2.142.6.1.1 NAME 'ldapsubentry' DESC 'LDAP Subentry class, version 1' SUP top  STRUCTURAL MAY cn  )",
   "( 1.3.6.1.4.1.2415.2.2.2.1 NAME 'scsubschema' DESC 'SWCOM subschema oc to store some more attributes in schema entry' SUP subschema  AUXILIARY MAY scschemafiletimestamp  )",
   "( 1.3.6.1.4.1.2415.2.2.2.2 NAME 'adminpolicy' SUP top  STRUCTURAL MUST cn  MAY ( adminattributeconstraint $ adminparentadminpolicy $ adminprovisiononly $ admintemplateonly $ description )  )",
   "( 1.3.6.1.4.1.2415.2.2.2.3 NAME 'adminroot' SUP top  STRUCTURAL MUST cn  MAY ( adminpolicydefaultdn $ adminallocrules )  )",
   "( 1.3.6.1.4.1.2415.2.2.2.4 NAME 'maildomain' SUP top  AUXILIARY MUST ( domainname $ domaintype )  MAY ( mailrelayhost $ mailrewritedomain $ mailwildcardaccount )  )",
   "( 1.3.6.1.4.1.2415.2.2.2.8 NAME 'adminallocation' SUP top  AUXILIARY MAY ( adminmaxrealms $ adminnumrealms $ adminmaxdomains $ adminnumdomains $ adminmaxmaildomains $ adminnummaildomains $ adminmaxorgs $ adminnumorgs $ adminmaxorgunits $ adminnumorgunits $ adminmaxusers $ adminnumusers $ adminmaxmailinglists $ adminnummailinglists $ adminmaxstoragekb $ adminusedstoragekb $ adminmaxsmtp $ adminnumsmtp $ adminmaxsmtpssl $ adminnumsmtpssl $ adminmaxpop $ adminnumpop $ adminmaxpopssl $ adminnumpopssl $ adminmaximap $ adminnumimap $ adminmaximapssl $ adminnumimapssl $ adminmaxselfcare $ adminnumselfcare $ adminmaxintermanager $ adminnumintermanager $ adminmaxwebmail $ adminnumwebmail $ adminmaxwebmailssl $ adminnumwebmailssl $ adminmaxmobilemail $ adminnummobilemail $ adminallocsubtots $ adminpolicydnused )  )",
   "( 1.3.6.1.4.1.2415.2.2.2.10 NAME 'adminrole' SUP top  STRUCTURAL MUST ( cn $ adminaccesslevel )  MAY ( admincreaterealm $ admindeleterealm $ admincreatepeeradmingroup $ admindeletepeeradmingroup $ admincreatesubadmingroup $ admindeletesubadmingroup $ admincreatepeeradminpolicy $ admindeletepeeradminpolicy $ admincreatesubadminpolicy $ admindeletesubadminpolicy $ adminallowedcreateclasses $ adminallowedupdateclasses )  )",
   "( 1.3.6.1.4.1.2415.2.2.2.11 NAME 'admingroup' SUP groupofnames  STRUCTURAL MUST adminroledn  MAY ( adminalloweddomains $ adminallowedadminpolicydn $ adminparentdomains $ adminattributeconstraint $ adminallowedmessagestorehosts $ adminallowedautoreplyhosts $ adminsuperiorattributeconstraint $ contactinfo )  )",
   "( 1.3.6.1.4.1.2415.2.2.2.12 NAME 'maillocaluserprefs' SUP top  AUXILIARY )",
   "( 1.3.6.1.4.1.2415.2.2.2.13 NAME 'scconfig' DESC 'Configuration object' SUP top  STRUCTURAL MUST cn  MAY scattributeindexinfo  )",
   "( 1.3.6.1.4.1.2415.2.2.2.16 NAME 'partition' DESC 'Partition Definitions' SUP top  STRUCTURAL MUST cn  MAY partition  )",
   "( 1.3.6.1.4.1.2415.2.2.2.17 NAME 'mailinglist' SUP top  STRUCTURAL MUST ( cn $ mail $ listlocalsubscriptionoption $ listremotesubscriptionoption $ listsubscriptionmoderationmethod $ listverifysubscriberequest $ listunsubscriptionoption $ listunsubscriptionmoderationmethod $ listverifyunsubscriberequest $ listaccesssubscriberlistoption $ listsubscriberpostingoption $ listnonsubscriberpostingoption $ listpostingmoderationmethod $ listdetectrequest $ listdeliverymode $ listaddressexpansionstyle $ listquotamaxsubscribers $ listquotamaxmsgsizekb $ listquotamaxmsgsperday $ listquotamaxvolumekbperday )  MAY ( description $ listextendedlocaldomains $ listwelcomemessage $ listgoodbyemessage $ listprologuetext $ listepiloguetext $ listheaderstobeadded $ listheaderstoberemoved $ listheaderstorewrite $ listremovexheaders $ listapprovedposters $ listdigestvolumenumber $ listdigestissuenumber $ listdigestdeliverytime $ liststatsdeliverytime $ listlastdigestdelivery $ listlaststatsdelivery $ listmaxbouncespersubscriber $ liststatsmessages $ liststatsvolume $ liststatsnewsubscribers $ liststatsunsubscribers $ liststatsforcedunsubscribers $ liststatsmessageswaiting $ liststatssubscriberswaiting $ liststatsunsubscriberswaiting $ liststatisticsnotification $ listbouncenotification $ listoverlimitnotification $ listsuppressnotifications $ listdynamic $ listdynamicbase $ listdynamicfilter )  )",
   "( 1.3.6.1.4.1.2415.2.2.2.18 NAME 'mailinglistowner' SUP top  STRUCTURAL MUST mail  )",
   "( 1.3.6.1.4.1.2415.2.2.2.19 NAME 'mailinglistrequest' SUP top  STRUCTURAL MUST mail  )",
   "( 1.3.6.1.4.1.2415.2.2.2.20 NAME 'mailinglistsubscriber' SUP top  STRUCTURAL MUST ( listsubscriberaddress $ listdeliverymode )  MAY ( liststatsmessages $ liststatsvolume $ liststatsbounces )  )",
   "( 1.3.6.1.4.1.2415.2.2.2.21 NAME 'adminuserprefs' SUP top  AUXILIARY MAY ( labeleduri $ adminpreferredlocale $ adminlastlogin )  )",
   "( 1.3.6.1.4.1.2415.2.2.2.22 NAME 'adminrealmspec' SUP top  STRUCTURAL MUST adminrealmtype  MAY ( admindefaultcreatedgroups $ admintargetobjectclass $ admindomainspeccontrol $ adminminallowedaccesslevel )  )",
   "( 1.3.6.1.4.1.2415.2.2.2.23 NAME 'adminalloccounts' SUP top  STRUCTURAL MUST cn  )",
   "( 1.3.6.1.4.1.2415.2.2.2.24 NAME 'dseroot' SUP top  STRUCTURAL MAY ( cn $ subschemasubentry $ changelog $ supportedldapversion $ firstchangenumber $ lastchangenumber $ lastexpirednumber $ firstentryid $ lastentryid $ supportedextension $ supportedcontrol )  )",
   "( 1.3.6.1.4.1.2415.2.60.2.1 NAME 'attridmap' DESC 'SWCOM oc to store attribute id to name mapping' AUXILIARY MUST attrid  )",
   "( 1.3.6.1.4.1.2415.2.60.2.51 NAME 'msguser' SUP top  AUXILIARY MAY ( mailboxid $ maillogin $ mailpassword $ mailpasswordtype $ mailboxstatus $ postaladdress $ postalcode $ msgsecretquestion $ msgsecretanswer )  )",
   "( 1.3.6.1.4.1.2415.2.60.2.52 NAME 'msguserprefs' SUP top  AUXILIARY MAY ( msglocale $ msgcharset $ msgtimezone )  )",
   "( 1.3.6.1.4.1.2415.2.3.2.2 NAME 'addressbookdistlist' AUXILIARY MAY displayname  )",
   "( 1.3.6.1.4.1.2415.2.3.2.3 NAME 'addressbookowner' AUXILIARY MAY addressbookdn  )",
   "( 1.3.6.1.4.1.2415.7.55.2.1 NAME 'senderscontrol' SUP top  STRUCTURAL MUST cn  MAY ( mailapprovedsenderslist $ mailblockedsenderslist )  )",
   "( 1.3.6.1.4.1.2415.3.35.2.4 NAME 'umphone' SUP top  STRUCTURAL MAY ( umivrflow $ umivrvariant )  )",
   "( 1.3.6.1.4.1.2415.3.35.2.7 NAME 'umdomain' SUP top  AUXILIARY MAY ( umenableautoprovisioning $ umautoprovisioningkeys $ umautoprovisioningminkey $ umautoprovisioningmaxkey $ umautoprovisioningadminpolicydn $ umautoprovisioningmaildomain $ umautoprovisioningmaillogin $ umautoprovisioningmailprefix $ umautoprovisioningmss $ umautoprovisioningpassword $ umautoprovisioningpin $ umautoprovisioningtargetnumberallowlist $ umautoprovisioningnotifytypes )  )",
   "( 1.3.6.1.4.1.2415.774.767.2.1 NAME 'notifyuserprefs' DESC 'Notification Provisioning' SUP top  AUXILIARY MAY ( notifydeleteemail $ notifybulkemail $ notifyfmtattchnone $ notifyfiltperuser $ notifybillingtype $ notifyservicelist $ notifyserviceoverride $ notifyattributelist $ notifyfmtrulegroupbasedn $ smsmin )  )",
   "( 1.3.6.1.4.1.2415.774.767.2.12 NAME 'notifyservice' DESC 'List of Event Types associated with the service' SUP top  AUXILIARY MUST notifyfiltruleeventlist  MAY description  )",
   "( 1.3.6.1.4.1.2415.774.767.2.13 NAME 'notifyfilterrule' DESC 'Notification Filter Rule' SUP top  STRUCTURAL MUST ( notifyfiltrulename $ notifyfiltrulescope )  MAY ( notifyfiltrulevalue $ notifyfiltprofile $ notifyfiltruleservice $ notifyfiltshareddn $ notifyfiltactive $ notifyfiltrulelanguage $ notifyfiltdefaultaction $ description )  )",
   "( 1.3.6.1.4.1.2415.774.767.2.14 NAME 'notifyruleset' DESC 'Notification Rule Set' SUP top  STRUCTURAL MUST notifyrulesetname  MAY description  )",
   "( 1.3.6.1.4.1.2415.774.767.2.15 NAME 'notifyformatrule' DESC 'Notification Format Rule' SUP top  STRUCTURAL MAY ( notifyfmtrulelocale $ notifyfmtrulevalue $ description )  )",
   "( 1.3.6.1.4.1.2415.774.767.2.16 NAME 'notifyfmtrulegroup' DESC 'Notification Format Rule Group' SUP top  STRUCTURAL MUST ( notifyfmtrulegroupname $ notifyfmtrulegrouptype )  MAY ( notifyfmtrulegroupservice $ notifyfmtrulegroupntfntype $ notifyfmtrulegroupeventtype $ notifyfmtrulegroupdlvtype $ description )  )",
   "( 1.3.6.1.4.1.2415.2.3.2.1 NAME 'addressbookperson' SUP top  STRUCTURAL MAY ( givenname $ sn $ nickname $ middlename $ mailprimaryaddress $ o $ departmentnumber $ title $ labeleduri $ telephonenumber $ mobile $ facsimiletelephonenumber $ pager $ otherphonenumber $ postaladdress $ worklink $ homepostaladdress $ birthday $ anniversary $ notes $ mailsecondaryaddress $ personaltitle $ displayname $ homephone $ homefacsimiletelephonenumber $ homemobile $ homepager $ homelink $ spousename $ gender $ childname $ usercertificate $ userpkcs12 $ jpegphoto $ buddyname $ improvider )  )",
   "( 1.3.6.1.4.1.2415.2.3.2.4 NAME 'corpaddressbookperson' SUP top  AUXILIARY MUST corpmailprimaryaddress  MAY ( givenname $ sn $ nickname $ middlename $ o $ departmentnumber $ title $ labeleduri $ telephonenumber $ mobile $ facsimiletelephonenumber $ pager $ otherphonenumber $ postaladdress $ worklink $ homepostaladdress $ birthday $ anniversary $ notes $ mailsecondaryaddress $ personaltitle $ displayname $ homephone $ homefacsimiletelephonenumber $ homemobile $ homepager $ homelink $ spousename $ gender $ childname $ usercertificate $ userpkcs12 $ jpegphoto $ buddyname $ improvider )  )",
   "( 1.3.6.1.4.1.2415.2.2.2.7 NAME 'adminrealm' SUP top  STRUCTURAL MUST cn  MAY ( billingid $ contactinfo $ adminpolicygrantdn $ adminattributeconstraint $ adminsuperiorattributeconstraint $ adminapprovedsenderslist $ adminblockedsenderslist $ adminparentalrejectaction $ adminparentalrejectinfo $ adminparentaldefaultdisposition $ adminbmimailwallspamactionverb $ admintargetdn $ corpaddressbookallowed $ corpaddressbookwanted $ adminfamilymaxusers $ adminfamilymaxstoragekb )  )",
   "( 1.3.6.1.4.1.2415.2.2.2.9 NAME 'admintarget' SUP top  AUXILIARY MUST adminrealmdn  MAY ( addressbookdn $ adminrealmspecdn )  )",
   "( 1.3.6.1.4.1.2415.8.2.1 NAME 'netmailuser' SUP top  AUXILIARY MAY ( netmailautocollect $ netmailmsgsperpage $ netmailreplyformat $ netmaildefaulteditor $ netmailmsglistcols $ netmailautopopemail $ netmailpopemailacctselect $ netmailactivealias $ netmailpopacctdetails $ netmailabentriesperpage $ netmailenablevoice $ netmailenablefax $ netmailcurrentver $ netmailsendreturnreceipt $ netmobilemailabsortby $ netmobilemailabdisplayby $ netmailaddressbookcontactlistmax $ netmailmsgviewprivacyfilter $ netmailrequestreturnreceipt $ netmailautospellcheck $ netmailusetrash $ netmailsignaturebeforereply )  )",
   "( 1.3.6.1.4.1.2415.7.55.2.2 NAME 'metadata' SUP top  STRUCTURAL MUST cn  MAY metavalue  )",
   "( 1.3.6.1.4.1.2415.2.2.2.14 NAME 'scconfigroot' DESC 'Configuration Root' SUP top  STRUCTURAL MUST cn  MAY ( sccachedirdbstatus $ lastentryid )  )",
   "( 2.5.6.10 NAME 'residentialperson' SUP person  STRUCTURAL MUST l  MAY ( businesscategory $ x121address $ registeredaddress $ destinationindicator $ preferreddeliverymethod $ telexnumber $ teletexterminalidentifier $ telephonenumber $ internationalisdnnumber $ facsimiletelephonenumber $ street $ postofficebox $ postalcode $ postaladdress $ physicaldeliveryofficename $ st )  )",
   "( 1.3.6.1.4.1.2415.3.35.2.3 NAME 'umphonenumber' SUP top  AUXILIARY MAY ( umpn $ umpntype $ umpnstatus $ umpnlabel $ umpngreetings $ umpnlocale $ umid )  )",
   "( 1.3.6.1.4.1.2415.3.35.2.6 NAME 'umrealm' SUP top  AUXILIARY MAY ( umdbnmaxnamestoprompt $ umdbnmindigitstoenter $ umrealmlocale $ umuserlocalelist $ umcallerlocalelist $ umemaillocalelist $ umdbnkeypad $ umdbnnameorder $ umivraccesslockperiod $ umoffsystemdeliveryoption )  )",
   "( 1.3.6.1.4.1.2415.3.35.2.8 NAME 'umabextension' SUP top  AUXILIARY MUST umabentryid  MAY ( umivrdefaultringbacktone $ umivravailringbacktones )  )",
   "( 1.3.6.1.4.1.2415.2.2.2.15 NAME 'replagreement' DESC 'Replication Agreement' SUP top  STRUCTURAL MUST ( cn $ updateinterval )  MAY ( replarea $ supplierreference $ consumeridentity $ consumerpassword $ lastchangenumber $ lastupdatedtime $ updateintervalas100millisecs $ nextupdatetime $ lastlcnchgtime $ createhost $ masterserverrole )  )",
   "( 2.16.840.1.113730.3.2.1 NAME 'changelogentry' SUP top  STRUCTURAL MUST ( changenumber $ targetdn $ changetype )  MAY ( changes $ newrdn $ deleteoldrdn $ newsuperior $ entry $ transactid $ createhost $ targetpartitionname )  )",
   "( 1.3.6.1.4.1.2415.3.35.2.5 NAME 'umspecialuserprefs' SUP top  AUXILIARY MAY ( umivrcallerinputtype $ umivrenablebusyrnaoption $ umivrenablecallermenu $ umivrecpcallermenu $ umivrnumringsbeforetransfer $ umivrpoundkeycontrol $ umivrstarkeycontrol $ umivrstarkeymailbox $ umivrecpmaxnoinput $ umivrecpmaxnomatch $ umivrcallforwardingmethod $ umivrextensiontype $ umivrphoneextensionprefix $ umivrspecialmailboxtype $ umivrholidaygreetcontrol $ umivrweekendgreetcontrol $ umivrafterhoursgreetcontrol $ ummediaonholdsource )  )",
   "( 1.3.6.1.4.1.2415.3.35.2.1 NAME 'umuser' SUP top  AUXILIARY MAY ( umpin $ umpinlastmodifytime $ umpwdlastmodifytime $ umprimaryfaxnumber $ umsecondaryfaxnumber $ umivrscheduledgreetingssettings $ umivroperatorschedulesettings $ umivrpersonaloperator $ umaccountlastaccesstime $ umivrgeneralmsgmailbox $ umivrcligreetingprefs $ umivrnonsubscribernameprefs $ umivraccesslastlocktime )  )",
   "( 1.3.6.1.4.1.2415.2.2.2.5 NAME 'mailuser' SUP top  AUXILIARY MUST ( mail $ adminpolicydn )  MAY ( billingid $ mailalternateaddress $ mailautoreplyhost $ mailboxid $ mailboxstatus $ mailforwardingaddress $ maillogin $ mailmessagestore $ mailpassword $ mailpasswordtype $ mailpopproxyhost $ mailsmtprelayhost $ mailscoperestrictedaddress $ mailfrom $ mailreplyto $ mailsignature $ mailvcard $ mailrejectaction $ mailrejectinfo )  )",
   "( 1.3.6.1.4.1.2415.2.2.2.6 NAME 'mailuserprefs' SUP top  AUXILIARY MAY ( mailforwarding $ mailparentalcontrol $ maildeliveryoption $ mailautoreplymode $ mailmtafilter $ mailmtafilterperuser $ mailsmtpauth $ mailsmtpaccess $ maildeliveryaccess $ mailsmtpsslaccess $ mailpopaccess $ mailpopsslaccess $ mailimapaccess $ mailimapsslaccess $ mailselfcare $ mailselfcaressl $ mailintermanager $ mailintermanagerssl $ mailquotabouncenotify $ mailquotatotkb $ mailquotamaxmsgkb $ mailquotamaxmsgs $ mailquotathreshold $ mailfolderquota $ mailbypassauthentication $ mailwebmailaccess $ mailwebmailsslaccess $ mailwebmailattachsizelimit $ mailwebmailmsgattachlimit $ mailwebmailattachlimit $ mailwebdisplay $ mailmobilemailaccess $ maildeliveryscope $ maildeniedsender $ maildeniedsenderaction $ maildeniedsendermessage $ mailwebmailaddressbooklimit $ mailwebmailaddressbooklistlimit $ mailwebmailusesignature $ mailwebmailconfirmdelete $ mailallowtheseips $ mailldapaccess $ mersenabled $ mersconfiguration $ mersfilebase $ mersfilesizekb $ mersmaxheaderlength $ mailrealm $ mailquotasendermaxmsgkb $ mailfuturedeliveryenabled $ mailfuturedeliveryquota $ mailfuturedeliverypending $ mailfuturedeliverymax $ mailimapproxyhost $ mailextensionsserviceattributes $ mailwebmaildeliveredtoaddress $ mailwebmaildeliveredtoaddresslist $ mailautosave $ mailautosignature $ mailautovcard $ mailincludeoriginal $ mailfamilymailbox $ mailwebmailexternalinboxserver $ mailbmimailwallspamactionverb $ mailbmimailwallvirusactionverb $ mailbmimailwallactioninfo $ mailpasswordhmac $ mailblocksendersaccess $ mailblocksendersactive $ mailapopaccess $ mailwebmailchangepassword $ mailpopunifyenabled $ mailpopunifyhost $ mailblocksenderspabaccess $ mailblocksenderspabactive $ mailsmtpenforcefrom $ mailindexhost $ mailsearchhost $ mailpopunifylogin $ mailpopunifypassword )  )",
   "( 1.3.6.1.4.1.2415.3.35.2.2 NAME 'umuserprefs' SUP top  AUXILIARY MAY ( umpinpwdcheckexpiration $ umpinpwdcheckrules $ umenablevoicemail $ umenablefax $ umenablefaxautoprint $ umenableundeliverablenotification $ umenabledeliveryconfirmation $ umenablecheckreceipt $ umenableanonymousdelivery $ umenableprivatedelivery $ umenableurgentdelivery $ umenableundeletemsgs $ umsendvoicecontrol $ umvoiceoutdialcontrol $ umsendfaxcontrol $ umfaxoutdialcontrol $ umdestoutdialcontrol $ umivrenableasr $ ummaxphonenumbers $ ummaxfaxes $ ummaxfaxpages $ umvmmsdomain $ umivrenableautologin $ umivrenablevolumecontrol $ umivrenablespeedcontrol $ umivrenabletutorial $ umivrenablenamegreeting $ umivrenablepersonalgreeting $ umivrenablebusygreeting $ umivrenableskipusergreeting $ umivrenableskipcallergreeting $ umivrenableusertransfer $ umivrenablenestedvdls $ umivrcallertransfercontrol $ umivrautoplaycontrol $ umivrextendedabsencecontrol $ umivrmsgagingcontrol $ umivrplaybackorder $ umivrpersonaloperatordefault $ umivrmaxgreetingsecs $ umivrmaxmsgsecs $ umivrmaxcaptionsecs $ umivrmaxnewmsgdays $ umivrmaxsavedmsgdays $ umivrmaxvdls $ umivrmaxvdlentries $ umivrmaxvdlnamesecs $ umivrmaxnamesecs $ umivrtutorialentryname $ umivrskippin $ umivrautoprint $ umivrautoplay $ umivrplaytutorial $ umivrplaydatetime $ umivrpromptlevel $ umivrcallerlocales $ umivrflow $ umivrvariant $ umivrtimeentryformat $ umivrgeneralgreetings $ umenableemail $ umenableautoplayemail $ umwebenablereplyvoicefax $ umenablefuturedelivery $ umenablevideo $ umvmmspn $ umenableemptycallcapture $ ummessagedeliveryoptions $ umivrenablescheduledgreetings $ umivrcalleridrestricted $ umivrnumdigitsinextension $ umaddonservicelist $ umholidaylist $ umserviceslist $ umivrplaynameifavailable $ umivrfmfmmaxphonenumbers $ umivrfmfmphonenumber $ umdestsearchparam $ umivrenablephonelabels $ umfmballowduplicatepin $ umfmbchildattrlist $ umfmballowupdatebychild $ umivrenableavatarcontrol $ umivravatarprefs $ umivrmaxringbacktones $ umivrringbacktoneprefs $ umivrdefaultringbacktone $ umivravailringbacktones $ umivrmaxcelebgreetings $ umivrcelebgreetingprefs $ umivrdefaultcelebgreeting $ umivravailcelebgreetings $ umivrmaxcelebcligreetings $ umivrtriggerapps $ umivrtriggerappsdefault $ umivrmaxcligreetings $ umivrenablevdlcligreetings $ umivremaillangprefs $ umaggregatentfnprofile $ umntfnerroraction $ umntfnretrycriteria $ umpinmaxlength $ umpinminlength $ umpinpwdrules $ umpinpwdlifetimedays $ umservicecontrollist $ umivrenableplaycallbacknumber $ umivrplayonlymsghdrs $ umivrplayaniifavailable $ umivrenablecelebgreetings $ umivrenableringbacktones $ umivrallowadminaccess $ umivrenableadmincommercialtransfer $ umivrusertype $ umivrenablebbmailbox $ umenablecommercialgdluserprefs $ umenablebroadcast $ umivrenablebroadcastuserprefs $ umivrenablespeechtotext $ umenablespeechtotext $ umspeechtotextprioritysettings $ umivrenablelistenin $ umivrlistenintriggernumbers $ umivrenablelivereplyconf $ umivrconfmediaonhold $ umspeechtotexttranscriptionsettings $ umivrenableexchangetts $ umenableexchangetts $ umexchangeserveraddress $ umexchangeserverusername $ umexchangeserveruserpassword $ umivrenablereminderuserprefs $ umenablereminder $ umenablecontentsearch $ addressbookprovider $ umnabusername $ umnabpassword )  )"],
 "dITContentRules"=>[],
 "ldapSyntaxes"=>[],
 "attributeTypes"=>
  ["( 2.5.21.5 NAME 'attributetypes' EQUALITY objectIdentifierFirstComponentMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.3 USAGE directoryOperation )",
   "( 2.5.21.6 NAME 'objectclasses' EQUALITY objectIdentifierFirstComponentMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.37 USAGE directoryOperation )",
   "( 2.5.21.4 NAME 'matchingrules' EQUALITY objectIdentifierFirstComponentMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.30 USAGE directoryOperation )",
   "( 2.5.21.8 NAME 'matchingruleuse' EQUALITY objectIdentifierFirstComponentMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.31 USAGE directoryOperation )",
   "( 2.5.21.1 NAME 'ditstructurerules' EQUALITY integerFirstComponentMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.17 USAGE directoryOperation )",
   "( 2.5.21.7 NAME 'nameforms' EQUALITY objectIdentifierFirstComponentMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.35 USAGE directoryOperation )",
   "( 2.5.21.2 NAME 'ditcontentrules' EQUALITY objectIdentifierFirstComponentMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.16 USAGE directoryOperation )",
   "( 2.5.18.1 NAME 'createtimestamp' EQUALITY generalizedTimeMatch ORDERING generalizedTimeOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.24 SINGLE-VALUE NO-USER-MODIFICATION USAGE directoryOperation )",
   "( 2.5.18.2 NAME 'modifytimestamp' EQUALITY generalizedTimeMatch ORDERING generalizedTimeOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.24 SINGLE-VALUE NO-USER-MODIFICATION USAGE directoryOperation )",
   "( 2.5.18.3 NAME 'creatorsname' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE NO-USER-MODIFICATION USAGE directoryOperation )",
   "( 2.5.18.4 NAME 'modifiersname' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE NO-USER-MODIFICATION USAGE directoryOperation )",
   "( 2.5.18.10 NAME 'subschemasubentry' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE NO-USER-MODIFICATION USAGE directoryOperation )",
   "( 1.3.6.1.4.1.1466.101.120.5 NAME 'namingcontexts' SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 USAGE dSAOperation )",
   "( 1.3.6.1.4.1.1466.101.120.6 NAME 'altserver' SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 USAGE dSAOperation )",
   "( 1.3.6.1.4.1.1466.101.120.7 NAME 'supportedextension' EQUALITY objectIdentifierMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.38 USAGE dSAOperation )",
   "( 1.3.6.1.4.1.1466.101.120.13 NAME 'supportedcontrol' EQUALITY objectIdentifierMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.38 USAGE dSAOperation )",
   "( 1.3.6.1.4.1.1466.101.120.14 NAME 'supportedsaslmechanisms' SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 USAGE dSAOperation )",
   "( 1.3.6.1.4.1.1466.101.120.15 NAME 'supportedldapversion' SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  USAGE dSAOperation )",
   "( 2.5.4.0 NAME 'objectclass' EQUALITY objectIdentifierMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.38 )",
   "( 2.5.4.1 NAME 'aliasedobjectname' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE )",
   "( 2.5.4.2 NAME 'knowledgeinformation' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15{32768}  )",
   "( 2.5.4.3 NAME 'cn' SUP name )",
   "( 2.5.4.4 NAME 'sn' SUP name SINGLE-VALUE )",
   "( 2.5.4.5 NAME 'serialnumber' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{64}  )",
   "( 2.5.4.6 NAME 'c' SUP name SINGLE-VALUE )",
   "( 2.5.4.7 NAME 'l' SUP name )",
   "( 2.5.4.8 NAME 'st' SUP name )",
   "( 2.5.4.9 NAME 'street' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15{128}  )",
   "( 2.5.4.10 NAME 'o' SUP name )",
   "( 2.5.4.11 NAME 'ou' SUP name )",
   "( 2.5.4.12 NAME 'title' SUP name )",
   "( 2.5.4.13 NAME 'description' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15{1024}  )",
   "( 2.5.4.15 NAME 'businesscategory' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15{128}  )",
   "( 2.5.4.16 NAME 'postaladdress' EQUALITY caseIgnoreListMatch SUBSTR caseIgnoreListSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.41 )",
   "( 2.5.4.17 NAME 'postalcode' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15{40}  )",
   "( 2.5.4.18 NAME 'postofficebox' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15{40}  )",
   "( 2.5.4.19 NAME 'physicaldeliveryofficename' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15{128}  )",
   "( 2.5.4.20 NAME 'telephonenumber' EQUALITY telephoneNumberMatch SUBSTR telephoneNumberSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.50{32}  )",
   "( 2.5.4.21 NAME 'telexnumber' SYNTAX 1.3.6.1.4.1.1466.115.121.1.52 )",
   "( 2.5.4.22 NAME 'teletexterminalidentifier' SYNTAX 1.3.6.1.4.1.1466.115.121.1.51 )",
   "( 2.5.4.23 NAME 'facsimiletelephonenumber' SYNTAX 1.3.6.1.4.1.1466.115.121.1.22 )",
   "( 2.5.4.24 NAME 'x121address' EQUALITY numericStringMatch ORDERING numericStringOrderingMatch SUBSTR numericStringSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{15}  )",
   "( 2.5.4.25 NAME 'internationalisdnnumber' EQUALITY numericStringMatch ORDERING numericStringOrderingMatch SUBSTR numericStringSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{16}  )",
   "( 2.5.4.26 NAME 'registeredaddress' SUP postalAddress SYNTAX 1.3.6.1.4.1.1466.115.121.1.41 )",
   "( 2.5.4.27 NAME 'destinationindicator' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{128}  )",
   "( 2.5.4.28 NAME 'preferreddeliverymethod' SYNTAX 1.3.6.1.4.1.1466.115.121.1.14 SINGLE-VALUE )",
   "( 2.5.4.29 NAME 'presentationaddress' EQUALITY presentationAddressMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.43 SINGLE-VALUE )",
   "( 2.5.4.30 NAME 'supportedapplicationcontext' EQUALITY objectIdentifierMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.38 )",
   "( 2.5.4.31 NAME 'member' SUP distinguishedName X-REFERENCES 'dn' )",
   "( 2.5.4.32 NAME 'owner' SUP distinguishedName )",
   "( 2.5.4.33 NAME 'roleoccupant' SUP distinguishedName )",
   "( 2.5.4.34 NAME 'seealso' SUP distinguishedName )",
   "( 2.5.4.35 NAME 'userpassword' EQUALITY octetStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.40{128}  )",
   "( 2.5.4.36 NAME 'usercertificate' SYNTAX 1.3.6.1.4.1.1466.115.121.1.8 )",
   "( 2.5.4.37 NAME 'cacertificate' SYNTAX 1.3.6.1.4.1.1466.115.121.1.8 )",
   "( 2.5.4.38 NAME 'authorityrevocationlist' SYNTAX 1.3.6.1.4.1.1466.115.121.1.9 )",
   "( 2.5.4.39 NAME 'certificaterevocationlist' SYNTAX 1.3.6.1.4.1.1466.115.121.1.9 )",
   "( 2.5.4.40 NAME 'crosscertificatepair' SYNTAX 1.3.6.1.4.1.1466.115.121.1.10 )",
   "( 2.5.4.41 NAME 'name' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15{32768}  )",
   "( 2.5.4.42 NAME 'givenname' SUP name )",
   "( 2.5.4.43 NAME 'initials' SUP name )",
   "( 2.5.4.44 NAME 'generationqualifier' SUP name )",
   "( 2.5.4.45 NAME 'x500uniqueidentifier' EQUALITY bitStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.6 )",
   "( 2.5.4.46 NAME 'dnqualifier' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 )",
   "( 2.5.4.47 NAME 'enhancedsearchguide' SYNTAX 1.3.6.1.4.1.1466.115.121.1.21 )",
   "( 2.5.4.48 NAME 'protocolinformation' EQUALITY protocolInformationMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.42 )",
   "( 2.5.4.49 NAME 'distinguishedname' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 )",
   "( 2.5.4.50 NAME 'uniquemember' EQUALITY uniqueMemberMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.34 )",
   "( 2.5.4.51 NAME 'houseidentifier' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15{32768}  )",
   "( 2.5.4.52 NAME 'supportedalgorithms' SYNTAX 1.3.6.1.4.1.1466.115.121.1.49 )",
   "( 2.5.4.53 NAME 'deltarevocationlist' SYNTAX 1.3.6.1.4.1.1466.115.121.1.9 )",
   "( 2.5.4.54 NAME 'dmdname' SUP name )",
   "( 0.9.2342.19200300.100.1.25 NAME 'dc' EQUALITY caseIgnoreIA5Match ORDERING caseIgnoreIA5OrderingMatch SUBSTR caseIgnoreIA5SubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE )",
   "( 2.16.840.1.113730.3.1.5 NAME 'changenumber' DESC 'a number which uniquely identifies a change made to a directory entry' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 2.16.840.1.113730.3.1.6 NAME 'targetdn' DESC 'the DN of the entry which was modified' EQUALITY distinguishedNameMatch SUBSTR distinguishedNameSubstringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE )",
   "( 2.16.840.1.113730.3.1.7 NAME 'changetype' DESC 'the type of change made to an entry' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 2.16.840.1.113730.3.1.8 NAME 'changes' DESC 'a set of changes to apply to an entry' SYNTAX 1.3.6.1.4.1.1466.115.121.1.40 )",
   "( 2.16.840.1.113730.3.1.9 NAME 'newrdn' DESC 'the new RDN of an entry which is the target of a modrdn operation' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE )",
   "( 2.16.840.1.113730.3.1.10 NAME 'deleteoldrdn' DESC 'a flag which indicates if the old RDN should be retained as an attribute of the entry' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 )",
   "( 2.16.840.1.113730.3.1.11 NAME 'newsuperior' DESC 'the new parent of an entry which is the target of a moddn operation' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE )",
   "( 2.16.840.1.113730.3.1.35 NAME 'changelog' DESC 'the distinguished name of the entry which contains the set of entries comprising this server changelog' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 )",
   "( 2.16.840.1.113730.3.1.1 NAME 'carlicense' DESC 'vehicle license or registration plate' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 2.16.840.1.113730.3.1.2 NAME 'departmentnumber' DESC 'identifies a department within an organization' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 2.16.840.1.113730.3.1.241 NAME 'displayname' DESC 'preferred name of a person to be used when displaying entries' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 2.16.840.1.113730.3.1.3 NAME 'employeenumber' DESC 'numerically identifies an employee within an organization' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 2.16.840.1.113730.3.1.4 NAME 'employeetype' DESC 'type of employment for a person' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 0.9.2342.19200300.100.1.60 NAME 'jpegphoto' DESC 'a JPEG image' SYNTAX 1.3.6.1.4.1.1466.115.121.1.28 )",
   "( 2.16.840.1.113730.3.1.39 NAME 'preferredlanguage' DESC 'preferred written or spoken language for a person' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 2.16.840.1.113730.3.1.40 NAME 'usersmimecertificate' DESC 'signed message used to support S/MIME' SYNTAX 1.3.6.1.4.1.1466.115.121.1.40 )",
   "( 2.16.840.1.113730.3.1.216 NAME 'userpkcs12' DESC 'PKCS #12 PFX PDU for exchange of personal identity information' SYNTAX 1.3.6.1.4.1.1466.115.121.1.40 )",
   "( 0.9.2342.19200300.100.1.55 NAME 'audio' EQUALITY octetStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.40{250000}  )",
   "( 0.9.2342.19200300.100.1.20 NAME 'homephone' EQUALITY telephoneNumberMatch SUBSTR telephoneNumberSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.50 )",
   "( 0.9.2342.19200300.100.1.39 NAME 'homepostaladdress' EQUALITY caseIgnoreListMatch SUBSTR caseIgnoreListSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.41 )",
   "( 0.9.2342.19200300.100.1.3 NAME 'mail' EQUALITY caseIgnoreIA5Match ORDERING caseIgnoreIA5OrderingMatch SUBSTR caseIgnoreIA5SubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{256}  SINGLE-VALUE )",
   "( 0.9.2342.19200300.100.1.10 NAME 'manager' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 )",
   "( 0.9.2342.19200300.100.1.41 NAME 'mobile' EQUALITY telephoneNumberMatch SUBSTR telephoneNumberSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.50 )",
   "( 0.9.2342.19200300.100.1.42 NAME 'pager' EQUALITY telephoneNumberMatch SUBSTR telephoneNumberSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.50 )",
   "( 0.9.2342.19200300.100.1.6 NAME 'roomnumber' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15{256}  )",
   "( 0.9.2342.19200300.100.1.21 NAME 'secretary' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 )",
   "( 0.9.2342.19200300.100.1.7 NAME 'photo' EQUALITY octetStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.40 )",
   "( 0.9.2342.19200300.100.1.1 NAME 'uid' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15{256}  )",
   "( 1.3.6.1.4.1.250.1.57 NAME 'labeleduri' EQUALITY caseExactMatch ORDERING caseExactOrderingMatch SUBSTR caseExactSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 2.16.840.1.113730.3.1.16 NAME 'maildeliveryoption' DESC 'Standard Attribute' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,P,N,E,S' )",
   "( 2.16.840.1.113730.3.1.14 NAME 'mailautoreplymode' DESC 'Standard Attribute' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,N,R,E,V' )",
   "( 2.16.840.1.113730.3.1.17 NAME 'mailforwardingaddress' DESC 'Standard Attribute' EQUALITY caseIgnoreIA5Match ORDERING caseIgnoreIA5OrderingMatch SUBSTR caseIgnoreIA5SubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{256}  )",
   "( 2.16.840.1.113730.3.1.13 NAME 'mailalternateaddress' DESC 'alternate RFC 822 email address of this recipient' EQUALITY caseIgnoreIA5Match ORDERING caseIgnoreIA5OrderingMatch SUBSTR caseIgnoreIA5SubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{256}  )",
   "( 2.16.840.1.113730.3.1.34 NAME 'ref' DESC 'URL reference' EQUALITY caseExactIA5Match ORDERING caseExactIA5OrderingMatch SUBSTR caseExactIA5SubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 USAGE distributedOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.1 NAME 'adminpolicydn' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE X-REFERENCES '(objectclass=adminpolicy).dn' )",
   "( 1.3.6.1.4.1.2415.2.2.1.2 NAME 'adminmaxusers' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,-1-9223372036854775807' )",
   "( 1.3.6.1.4.1.2415.2.2.1.3 NAME 'adminnumusers' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.4 NAME 'domainname' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{255}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.5 NAME 'domaintype' EQUALITY caseExactMatch ORDERING caseExactOrderingMatch SUBSTR caseExactSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,L,R,N,I' )",
   "( 1.3.6.1.4.1.2415.2.2.1.6 NAME 'mailrelayhost' EQUALITY caseIgnoreIA5Match ORDERING caseIgnoreIA5OrderingMatch SUBSTR caseIgnoreIA5SubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{97}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.7 NAME 'mailrewritedomain' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{255}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.8 NAME 'mailwildcardaccount' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{64}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.9 NAME 'scschemafiletimestamp' EQUALITY generalizedTimeMatch ORDERING generalizedTimeOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.24 SINGLE-VALUE NO-USER-MODIFICATION USAGE directoryOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.10 NAME 'mailpopproxyhost' EQUALITY caseIgnoreIA5Match ORDERING caseIgnoreIA5OrderingMatch SUBSTR caseIgnoreIA5SubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{255}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.11 NAME 'mailsmtprelayhost' EQUALITY caseIgnoreIA5Match ORDERING caseIgnoreIA5OrderingMatch SUBSTR caseIgnoreIA5SubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{255}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.12 NAME 'mailautoreplyhost' EQUALITY caseIgnoreIA5Match ORDERING caseIgnoreIA5OrderingMatch SUBSTR caseIgnoreIA5SubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{255}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.13 NAME ( 'mailpassword' 'msgpassword' ) EQUALITY caseExactMatch ORDERING caseExactOrderingMatch SUBSTR caseExactSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15{64}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.14 NAME ( 'mailpasswordtype' 'msgpasswordtype' ) EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,C,M,U,S,H,1,2,3,4,5' )",
   "( 1.3.6.1.4.1.2415.2.2.1.15 NAME 'mailintermanagerssl' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.2.2.1.16 NAME 'mailimapsslaccess' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,all,trusted,none' )",
   "( 1.3.6.1.4.1.2415.2.2.1.17 NAME ( 'mailboxstatus' 'msguserstatus' ) EQUALITY caseExactMatch ORDERING caseExactOrderingMatch SUBSTR caseExactSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,A,D,S,L,M,P' )",
   "( 1.3.6.1.4.1.2415.2.2.1.19 NAME ( 'maillogin' 'msgusername' ) EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15{129}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.20 NAME ( 'mailboxid' 'msguserid' ) EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.21 NAME 'billingid' EQUALITY caseExactMatch ORDERING caseExactOrderingMatch SUBSTR caseExactSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.22 NAME 'updateinterval' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.2.2.1.23 NAME 'contactinfo' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.2.2.1.24 NAME 'mailpopaccess' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,all,trusted,none' )",
   "( 1.3.6.1.4.1.2415.2.2.1.25 NAME 'mailsmtpaccess' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.2.2.1.26 NAME 'mailimapaccess' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,all,trusted,none' )",
   "( 1.3.6.1.4.1.2415.2.2.1.27 NAME 'mailpopsslaccess' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,all,trusted,none' )",
   "( 1.3.6.1.4.1.2415.2.2.1.28 NAME 'mailsmtpsslaccess' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.2.2.1.29 NAME 'mailsmtpauth' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.2.2.1.30 NAME 'mailmtafilter' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.2.2.1.31 NAME 'mailquotabouncenotify' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.2.2.1.32 NAME 'mailforwarding' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.2.2.1.33 NAME 'replarea' SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 USAGE distributedOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.34 NAME 'mailselfcare' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.2.2.1.35 NAME 'mailselfcaressl' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.2.2.1.36 NAME 'mailintermanager' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.2.2.1.39 NAME 'mailquotamaxmsgs' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.2.2.1.40 NAME 'mailquotathreshold' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-100' )",
   "( 1.3.6.1.4.1.2415.2.2.1.41 NAME 'mailbypassauthentication' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.42 NAME 'mailwebmailaccess' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,all,trusted,none' )",
   "( 1.3.6.1.4.1.2415.2.2.1.43 NAME 'mailwebmailattachsizelimit' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.2.2.1.44 NAME 'mailwebmailmsgattachlimit' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.2.2.1.45 NAME 'mailwebmailattachlimit' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.2.2.1.46 NAME 'mailwebmailaddressbooklimit' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.2.2.1.47 NAME 'mailwebmailaddressbooklistlimit' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.2.2.1.48 NAME 'mailwebmailusesignature' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.2.2.1.49 NAME 'mailwebmailconfirmdelete' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.2.2.1.50 NAME 'mailwebdisplay' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.51 NAME 'mailmtafilterperuser' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.2.2.1.52 NAME 'supplierreference' SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE USAGE distributedOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.53 NAME 'consumeridentity' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE USAGE distributedOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.54 NAME 'consumerpassword' EQUALITY octetStringMatch ORDERING octetStringOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.40{128}  SINGLE-VALUE USAGE distributedOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.56 NAME 'lastchangenumber' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE NO-USER-MODIFICATION USAGE distributedOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.57 NAME 'adminpolicydefaultdn' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE X-REFERENCES 'dn' )",
   "( 1.3.6.1.4.1.2415.2.2.1.58 NAME 'firstchangenumber' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE NO-USER-MODIFICATION USAGE distributedOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.59 NAME 'partition' SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 USAGE distributedOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.60 NAME 'partitionname' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 USAGE distributedOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.61 NAME 'mailmessagestore' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.62 NAME 'adminapprovedsenderslist' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.2.2.1.63 NAME 'acirule' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.1 USAGE dSAOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.64 NAME 'mailparentalcontrol' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.2.2.1.65 NAME 'targetpartitionname' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 USAGE distributedOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.66 NAME 'adminpolicygrantdn' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 X-REFERENCES 'dn' )",
   "( 1.3.6.1.4.1.2415.2.2.1.67 NAME 'adminmaxrealms' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,-1-9223372036854775807' )",
   "( 1.3.6.1.4.1.2415.2.2.1.68 NAME 'adminsuperiorattributeconstraint' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.2.2.1.69 NAME 'adminparentalrejectaction' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,drop,forward' )",
   "( 1.3.6.1.4.1.2415.2.2.1.70 NAME 'admintargetdn' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 X-REFERENCES '(objectclass=adminTarget).dn' )",
   "( 1.3.6.1.4.1.2415.2.2.1.71 NAME 'adminmaxstoragekb' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,-1-9223372036854775807' )",
   "( 1.3.6.1.4.1.2415.2.2.1.72 NAME 'adminusedstoragekb' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.73 NAME 'adminmaxsmtpssl' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,-1-9223372036854775807' )",
   "( 1.3.6.1.4.1.2415.2.2.1.74 NAME 'adminnumsmtpssl' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.75 NAME 'adminmaxpop' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,-1-9223372036854775807' )",
   "( 1.3.6.1.4.1.2415.2.2.1.76 NAME 'adminnumpop' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.77 NAME 'adminmaxpopssl' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,-1-9223372036854775807' )",
   "( 1.3.6.1.4.1.2415.2.2.1.78 NAME 'adminnumpopssl' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.79 NAME 'adminmaximap' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,-1-9223372036854775807' )",
   "( 1.3.6.1.4.1.2415.2.2.1.80 NAME 'adminnumimap' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.81 NAME 'adminmaximapssl' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,-1-9223372036854775807' )",
   "( 1.3.6.1.4.1.2415.2.2.1.82 NAME 'adminnumimapssl' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.83 NAME 'adminmaxwebmail' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,-1-9223372036854775807' )",
   "( 1.3.6.1.4.1.2415.2.2.1.84 NAME 'adminnumwebmail' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.85 NAME 'adminmaxselfcare' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,-1-9223372036854775807' )",
   "( 1.3.6.1.4.1.2415.2.2.1.86 NAME 'adminnumselfcare' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.87 NAME 'adminmaxintermanager' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,-1-9223372036854775807' )",
   "( 1.3.6.1.4.1.2415.2.2.1.88 NAME 'adminnumintermanager' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.90 NAME 'adminmaxmailinglists' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,-1-9223372036854775807' )",
   "( 1.3.6.1.4.1.2415.2.2.1.91 NAME 'adminnummailinglists' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.92 NAME 'adminaccesslevel' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.93 NAME 'admincreaterealm' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.94 NAME 'admindeleterealm' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.95 NAME 'admincreatepeeradmingroup' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 X-REFERENCES 'dn' )",
   "( 1.3.6.1.4.1.2415.2.2.1.96 NAME 'admindeletepeeradmingroup' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 X-REFERENCES 'dn' )",
   "( 1.3.6.1.4.1.2415.2.2.1.97 NAME 'adminnumrealms' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.98 NAME 'admincreatesubadmingroup' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 X-REFERENCES 'dn' )",
   "( 1.3.6.1.4.1.2415.2.2.1.99 NAME 'admindeletesubadmingroup' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 X-REFERENCES 'dn' )",
   "( 1.3.6.1.4.1.2415.2.2.1.100 NAME 'adminmaxsmtp' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,-1-9223372036854775807' )",
   "( 1.3.6.1.4.1.2415.2.2.1.101 NAME 'admincreatepeeradminpolicy' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.102 NAME 'admindeletepeeradminpolicy' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.103 NAME 'admincreatesubadminpolicy' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.104 NAME 'admindeletesubadminpolicy' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.105 NAME 'adminmaxmaildomains' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,-1-9223372036854775807' )",
   "( 1.3.6.1.4.1.2415.2.2.1.106 NAME 'adminnummaildomains' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.107 NAME 'adminallowedcreateclasses' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.2.2.1.108 NAME 'adminallowedupdateclasses' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.2.2.1.109 NAME 'adminroledn' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE X-REFERENCES '(objectclass=adminRole).dn' )",
   "( 1.3.6.1.4.1.2415.2.2.1.110 NAME 'adminalloweddomains' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 )",
   "( 1.3.6.1.4.1.2415.2.2.1.111 NAME 'adminallowedadminpolicydn' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 X-REFERENCES '(objectclass=adminPolicy).dn' )",
   "( 1.3.6.1.4.1.2415.2.2.1.112 NAME 'adminparentdomains' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 )",
   "( 1.3.6.1.4.1.2415.2.2.1.113 NAME 'adminrealmdn' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE X-REFERENCES '(objectclass=adminRealm).dn' )",
   "( 1.3.6.1.4.1.2415.2.2.1.114 NAME 'adminattributeconstraint' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.2.2.1.115 NAME 'adminprovisiononly' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.116 NAME 'admintemplateonly' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.117 NAME 'mailallowtheseips' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{64}  )",
   "( 1.3.6.1.4.1.2415.2.2.1.118 NAME 'mailldapaccess' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,all,trusted,none' )",
   "( 1.3.6.1.4.1.2415.2.2.1.119 NAME 'listlocalsubscriptionoption' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,open,closed,closednotify,moderated' )",
   "( 1.3.6.1.4.1.2415.2.2.1.120 NAME 'listremotesubscriptionoption' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,open,closed,closednotify,moderated' )",
   "( 1.3.6.1.4.1.2415.2.2.1.121 NAME 'listsubscriptionmoderationmethod' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,web,email,both' )",
   "( 1.3.6.1.4.1.2415.2.2.1.122 NAME 'listverifysubscriberequest' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.123 NAME 'listunsubscriptionoption' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,open,closed,closednotify,moderated' )",
   "( 1.3.6.1.4.1.2415.2.2.1.124 NAME 'listunsubscriptionmoderationmethod' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,web,email,both' )",
   "( 1.3.6.1.4.1.2415.2.2.1.125 NAME 'listverifyunsubscriberequest' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.126 NAME 'listaccesssubscriberlistoption' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 )",
   "( 1.3.6.1.4.1.2415.2.2.1.127 NAME 'listsubscriberpostingoption' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,open,closed,closednotify,moderated' )",
   "( 1.3.6.1.4.1.2415.2.2.1.128 NAME 'listnonsubscriberpostingoption' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,open,closed,closednotify,moderated' )",
   "( 1.3.6.1.4.1.2415.2.2.1.129 NAME 'listpostingmoderationmethod' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,web,email,both' )",
   "( 1.3.6.1.4.1.2415.2.2.1.130 NAME 'listdetectrequest' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.131 NAME 'listdeliverymode' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,immediate,digest,both' )",
   "( 1.3.6.1.4.1.2415.2.2.1.132 NAME 'listaddressexpansionstyle' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,none,group,expand' )",
   "( 1.3.6.1.4.1.2415.2.2.1.133 NAME 'listquotamaxsubscribers' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.134 NAME 'listquotamaxmsgsizekb' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.135 NAME 'listquotamaxmsgsperday' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.136 NAME 'listquotamaxvolumekbperday' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.137 NAME 'listextendedlocaldomains' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 )",
   "( 1.3.6.1.4.1.2415.2.2.1.138 NAME 'listwelcomemessage' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.139 NAME 'listgoodbyemessage' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.140 NAME 'listprologuetext' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.141 NAME 'listepiloguetext' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.142 NAME 'listheaderstobeadded' EQUALITY caseIgnoreIA5Match ORDERING caseIgnoreIA5OrderingMatch SUBSTR caseIgnoreIA5SubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 )",
   "( 1.3.6.1.4.1.2415.2.2.1.144 NAME 'listheaderstorewrite' EQUALITY caseExactIA5Match ORDERING caseExactIA5OrderingMatch SUBSTR caseExactIA5SubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 )",
   "( 1.3.6.1.4.1.2415.2.2.1.145 NAME 'listremovexheaders' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.146 NAME 'listapprovedposters' EQUALITY caseIgnoreIA5Match ORDERING caseIgnoreIA5OrderingMatch SUBSTR caseIgnoreIA5SubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 )",
   "( 1.3.6.1.4.1.2415.2.2.1.147 NAME 'listdigestvolumenumber' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.148 NAME 'listdigestissuenumber' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.149 NAME 'listdigestdeliverytime' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 )",
   "( 1.3.6.1.4.1.2415.2.2.1.150 NAME 'liststatsdeliverytime' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 )",
   "( 1.3.6.1.4.1.2415.2.2.1.151 NAME 'listmaxbouncespersubscriber' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.152 NAME 'liststatsmessages' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.153 NAME 'liststatsvolume' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.154 NAME 'liststatsnewsubscribers' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.155 NAME 'liststatsunsubscribers' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.156 NAME 'liststatsforcedunsubscribers' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.157 NAME 'liststatsmessageswaiting' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.158 NAME 'liststatssubscriberswaiting' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.159 NAME 'liststatsunsubscriberswaiting' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.160 NAME 'liststatisticsnotification' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.161 NAME 'listbouncenotification' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.162 NAME 'listoverlimitnotification' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.163 NAME 'listdynamic' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.164 NAME 'listdynamicbase' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.165 NAME 'listsubscriberaddress' EQUALITY caseIgnoreIA5Match ORDERING caseIgnoreIA5OrderingMatch SUBSTR caseIgnoreIA5SubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{256}  )",
   "( 1.3.6.1.4.1.2415.2.2.1.166 NAME 'liststatsbounces' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.167 NAME 'adminpreferredlocale' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.168 NAME 'adminlastlogin' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.169 NAME 'sccachedirdbstatus' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.171 NAME 'adminparentadminpolicy' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE X-REFERENCES '(objectclass=adminPolicy).dn' )",
   "( 1.3.6.1.4.1.2415.2.2.1.172 NAME 'adminnumsmtp' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.173 NAME 'adminmaxdomains' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,-1-9223372036854775807' )",
   "( 1.3.6.1.4.1.2415.2.2.1.174 NAME 'adminnumdomains' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.70 NAME 'adminmaxorgs' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,-1-9223372036854775807' )",
   "( 1.3.6.1.4.1.2415.2.60.1.71 NAME 'adminnumorgs' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.72 NAME 'adminmaxorgunits' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,-1-9223372036854775807' )",
   "( 1.3.6.1.4.1.2415.2.60.1.73 NAME 'adminnumorgunits' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.175 NAME 'adminallocrules' EQUALITY caseIgnoreIA5Match ORDERING caseIgnoreIA5OrderingMatch SUBSTR caseIgnoreIA5SubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 )",
   "( 1.3.6.1.4.1.2415.2.2.1.176 NAME 'adminallocsubtots' SUP name )",
   "( 1.3.6.1.4.1.2415.2.2.1.177 NAME 'adminrealmtype' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,provider,org,ou,family,group' )",
   "( 1.3.6.1.4.1.2415.2.2.1.178 NAME 'admindefaultcreatedgroups' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 X-REFERENCES 'dn' )",
   "( 1.3.6.1.4.1.2415.2.2.1.179 NAME 'admintargetobjectclass' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 )",
   "( 1.3.6.1.4.1.2415.2.2.1.180 NAME 'admindomainspeccontrol' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.181 NAME 'adminminallowedaccesslevel' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.182 NAME 'adminpolicydnused' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 X-REFERENCES '(objectclass=adminPolicy).dn' )",
   "( 1.3.6.1.4.1.2415.2.2.1.184 NAME 'lastexpirednumber' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE USAGE distributedOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.185 NAME 'targetentryid' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.186 NAME 'entryid' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE NO-USER-MODIFICATION USAGE directoryOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.187 NAME 'objecttype' EQUALITY caseExactMatch ORDERING caseExactOrderingMatch SUBSTR caseExactSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15{32}  SINGLE-VALUE NO-USER-MODIFICATION USAGE directoryOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.188 NAME 'firstentryid' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE NO-USER-MODIFICATION USAGE directoryOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.189 NAME 'lastentryid' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE NO-USER-MODIFICATION USAGE directoryOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.190 NAME 'mersfilesizekb' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.191 NAME 'mersmaxheaderlength' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.192 NAME 'mersmssinstances' EQUALITY caseExactMatch ORDERING caseExactOrderingMatch SUBSTR caseExactSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.193 NAME 'mersenabled' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.194 NAME 'mersconfiguration' EQUALITY caseExactMatch ORDERING caseExactOrderingMatch SUBSTR caseExactSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.195 NAME 'mersfilebase' EQUALITY caseExactMatch ORDERING caseExactOrderingMatch SUBSTR caseExactSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.196 NAME 'changeid' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE NO-USER-MODIFICATION USAGE directoryOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.197 NAME 'listlastdigestdelivery' EQUALITY numericStringMatch ORDERING numericStringOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{14}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.198 NAME 'listlaststatsdelivery' EQUALITY numericStringMatch ORDERING numericStringOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{14}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.199 NAME 'listsuppressnotifications' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.200 NAME 'targetdomainname' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{255}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.201 NAME 'swcmrebuildentrydata' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE USAGE directoryOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.202 NAME 'maildeliveryscope' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,global,local' )",
   "( 1.3.6.1.4.1.2415.2.2.1.203 NAME 'maildeniedsender' DESC 'Senders from which a recipient will not accept mail.' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{256}  )",
   "( 1.3.6.1.4.1.2415.2.2.1.204 NAME 'maildeniedsenderaction' DESC 'The action taken when the account rejects mail from a sender.' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,bounce,reject,sideline,toss,none' )",
   "( 1.3.6.1.4.1.2415.2.2.1.205 NAME 'maildeniedsendermessage' DESC 'A message associated with the mailDeniedSenderAction.' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.207 NAME 'dn' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE NO-USER-MODIFICATION USAGE directoryOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.208 NAME 'parentid' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE NO-USER-MODIFICATION USAGE directoryOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.209 NAME 'clusterindex' DESC 'Cluster object attribute used to store cluster index information.' EQUALITY caseIgnoreMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.2.2.1.210 NAME 'clusterentryfilter' DESC 'Cluster object attribute used to store entry filter information.' EQUALITY caseIgnoreMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.2.2.1.211 NAME 'clusterrouters' DESC 'Cluster object attribute used to store list of router hosts.' EQUALITY caseIgnoreMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.212 NAME 'clusterentryservers' DESC 'Cluster object attribute used to store entry server hosts for a router' EQUALITY caseIgnoreMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.2.2.1.213 NAME 'clusterindexservers' DESC 'Cluster object attribute used to store index server hosts for a router' EQUALITY caseIgnoreMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.2.2.1.214 NAME 'targetnewpartitionname' DESC 'This attribute can appear in changelog entries.' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 USAGE distributedOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.215 NAME 'oldpartitionname' DESC 'This is a dummy attribute.' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 USAGE distributedOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.216 NAME 'newpartitionname' DESC 'This is a dummy attribute.' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 USAGE distributedOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.217 NAME 'entry' DESC 'complete entry in the changelog' SYNTAX 1.3.6.1.4.1.1466.115.121.1.40 )",
   "( 1.3.6.1.4.1.2415.2.2.1.218 NAME 'mailrealm' DESC 'The realm associated with an account.' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.219 NAME 'lastupdatedtime' EQUALITY generalizedTimeMatch ORDERING generalizedTimeOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.24 SINGLE-VALUE NO-USER-MODIFICATION USAGE distributedOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.220 NAME 'nextupdatetime' EQUALITY generalizedTimeMatch ORDERING generalizedTimeOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.24 SINGLE-VALUE NO-USER-MODIFICATION USAGE distributedOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.221 NAME 'lastlcnchgtime' EQUALITY generalizedTimeMatch ORDERING generalizedTimeOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.24 SINGLE-VALUE NO-USER-MODIFICATION USAGE distributedOperation )",
   "( 1.3.6.1.4.1.2415.2.2.1.222 NAME 'maildeliveryaccess' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.2.2.1.223 NAME 'mailimapproxyhost' EQUALITY caseIgnoreIA5Match SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{255}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.224 NAME 'mailwebmailexternalinboxserver' EQUALITY caseIgnoreIA5Match SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{255}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.225 NAME 'adminmaxwebmailssl' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,-1-9223372036854775807' )",
   "( 1.3.6.1.4.1.2415.2.2.1.226 NAME 'adminnumwebmailssl' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.227 NAME 'mailmobilemailaccess' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,all,trusted,none' )",
   "( 1.3.6.1.4.1.2415.2.2.1.228 NAME 'adminmaxmobilemail' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,-1-9223372036854775807' )",
   "( 1.3.6.1.4.1.2415.2.2.1.229 NAME 'adminnummobilemail' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.230 NAME 'mailpasswordhmac' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15{64}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.923.2.1.15 NAME 'mailwebmailsslaccess' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,all,trusted,none' )",
   "( 1.3.6.1.4.1.2415.2.2.1.301 NAME 'mailbmimailwallspamactionverb' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.302 NAME 'mailbmimailwallvirusactionverb' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.303 NAME 'mailbmimailwallactioninfo' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.306 NAME 'adminallowedmessagestorehosts' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 )",
   "( 1.3.6.1.4.1.2415.2.2.1.307 NAME 'adminallowedautoreplyhosts' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 )",
   "( 1.3.6.1.4.1.2415.2.2.1.308 NAME 'relateddn' DESC 'additional DNs this change log is related to' SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.2.60.1.1 NAME 'mailfuturedeliveryenabled' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.2.60.1.2 NAME 'mailfuturedeliveryquota' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.2.60.1.3 NAME 'mailfuturedeliverypending' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{256}  )",
   "( 1.3.6.1.4.1.2415.2.60.1.4 NAME 'mailfuturedeliverymax' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.2.60.1.5 NAME 'listdynamicfilter' EQUALITY caseIgnoreMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.2.60.1.7 NAME 'mailscoperestrictedaddress' DESC 'RFC 822 address identifying accounts restricted to local delivery' EQUALITY caseIgnoreIA5Match ORDERING caseIgnoreIA5OrderingMatch SUBSTR caseIgnoreIA5SubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{256}  )",
   "( 1.1.3.6.1.4.1.2415.2.60.1.51 NAME 'mailextensionsserviceattributes' DESC 'Defines the configuration for an extension service.' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.2.60.1.6 NAME 'attrid' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15{1024}  NO-USER-MODIFICATION )",
   "( 1.3.6.1.4.1.2415.2.52.1.2 NAME 'entrysize' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE NO-USER-MODIFICATION USAGE directoryOperation )",
   "( 1.3.6.1.4.1.2415.2.52.1.3 NAME 'mailwebmaildeliveredtoaddress' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.52.1.4 NAME 'mailwebmaildeliveredtoaddresslist' EQUALITY caseIgnoreIA5Match SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{255}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.52 NAME 'msgsecretquestion' EQUALITY caseIgnoreListMatch SUBSTR caseIgnoreListSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{256}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.53 NAME 'msgsecretanswer' EQUALITY caseIgnoreListMatch SUBSTR caseIgnoreListSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{256}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.54 NAME 'msglocale' EQUALITY caseIgnoreListMatch SUBSTR caseIgnoreListSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{256}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.55 NAME 'msgcharset' EQUALITY caseIgnoreListMatch SUBSTR caseIgnoreListSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{256}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.56 NAME 'msgtimezone' EQUALITY caseIgnoreListMatch SUBSTR caseIgnoreListSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{256}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.57 NAME 'mailfrom' EQUALITY caseIgnoreListMatch SUBSTR caseIgnoreListSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{256}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.58 NAME 'mailreplyto' EQUALITY caseIgnoreListMatch SUBSTR caseIgnoreListSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{256}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.59 NAME 'mailsignature' EQUALITY caseIgnoreListMatch SUBSTR caseIgnoreListSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{256}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.60 NAME 'mailvcard' EQUALITY caseIgnoreListMatch SUBSTR caseIgnoreListSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{256}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.61 NAME 'mailautosave' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.2.60.1.62 NAME 'mailautosignature' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.2.60.1.63 NAME 'mailautovcard' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.2.60.1.64 NAME 'mailincludeoriginal' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.2.60.1.65 NAME 'mailfamilymailbox' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2' )",
   "( 1.3.6.1.4.1.2415.2.52.1.7 NAME 'mailapopaccess' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2' )",
   "( 0.9.2342.19200300.100.1.40 NAME 'personaltitle' DESC 'contains values like Mr., Mrs., Miss, Dr. etc.' EQUALITY caseIgnoreMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15{256}  )",
   "( 1.3.6.1.4.1.2415.2.3.1.1 NAME 'nickname' SUP name )",
   "( 1.3.6.1.4.1.2415.2.3.1.2 NAME 'middlename' SUP name )",
   "( 1.3.6.1.4.1.2415.2.3.1.3 NAME 'otherphonenumber' EQUALITY telephoneNumberMatch SUBSTR telephoneNumberSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.50 )",
   "( 1.3.6.1.4.1.2415.2.3.1.4 NAME 'birthday' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.3.1.5 NAME 'anniversary' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.3.1.6 NAME 'notes' EQUALITY caseIgnoreMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.3.1.7 NAME 'mailsecondaryaddress' DESC 'alternate RFC 822 email address' EQUALITY caseIgnoreIA5Match SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{256}  )",
   "( 1.3.6.1.4.1.2415.2.3.1.8 NAME 'homefacsimiletelephonenumber' SYNTAX 1.3.6.1.4.1.1466.115.121.1.22 )",
   "( 1.3.6.1.4.1.2415.2.3.1.9 NAME 'homemobile' EQUALITY telephoneNumberMatch SUBSTR telephoneNumberSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.50 )",
   "( 1.3.6.1.4.1.2415.2.3.1.10 NAME 'homepager' EQUALITY telephoneNumberMatch SUBSTR telephoneNumberSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.50 )",
   "( 1.3.6.1.4.1.2415.2.3.1.11 NAME 'homelink' EQUALITY caseExactMatch SUBSTR caseExactSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.2.3.1.12 NAME 'worklink' EQUALITY caseExactMatch SUBSTR caseExactSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.2.3.1.13 NAME 'spousename' SUP name )",
   "( 1.3.6.1.4.1.2415.2.3.1.14 NAME 'gender' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.3.1.15 NAME 'childname' SUP name )",
   "( 1.3.6.1.4.1.2415.2.3.1.16 NAME 'addressbookdn' SUP distinguishedName )",
   "( 1.3.6.1.4.1.2415.2.3.1.17 NAME 'mailprimaryaddress' EQUALITY caseIgnoreIA5Match SUBSTR caseIgnoreIA5SubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{256}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.3.1.18 NAME 'corpmailprimaryaddress' EQUALITY caseIgnoreIA5Match SUBSTR caseIgnoreIA5SubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{256}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.67 NAME 'corpaddressbookallowed' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,true,blocked,false' )",
   "( 1.3.6.1.4.1.2415.2.60.1.68 NAME 'corpaddressbookwanted' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,true,false' )",
   "( 1.3.6.1.4.1.2415.7.55.1.1 NAME 'adminblockedsenderslist' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.7.55.1.2 NAME 'adminparentalrejectinfo' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.7.55.1.3 NAME 'adminparentaldefaultdisposition' EQUALITY caseIgnoreIA5Match SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,accept,reject' )",
   "( 1.3.6.1.4.1.2415.7.55.1.4 NAME 'mailblocksendersaccess' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.7.55.1.5 NAME 'mailblocksendersactive' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27{38}  SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.7.55.1.6 NAME 'mailapprovedsenderslist' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.7.55.1.7 NAME 'mailblockedsenderslist' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.7.55.1.8 NAME 'mailrejectaction' EQUALITY caseIgnoreIA5Match SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,drop,forward' )",
   "( 1.3.6.1.4.1.2415.7.55.1.9 NAME 'mailrejectinfo' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.7.55.1.10 NAME 'adminbmimailwallspamactionverb' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.1 NAME 'umpin' DESC 'User PIN' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.2 NAME 'umpinlastmodifytime' DESC 'Timestamp of latest PIN change' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.3 NAME 'umpwdlastmodifytime' DESC 'Timestamp of latest password change' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.4 NAME 'umprimaryfaxnumber' DESC 'Primary fax number to print to' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.5 NAME 'umvmmspn' DESC 'Voice MMS phone number in canonical form cc.rc.line[-ext]' EQUALITY caseExactMatch SUBSTR caseExactSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.6 NAME 'umivrpersonaloperator' DESC 'Phone number for personal assistant-operator' EQUALITY caseExactMatch SUBSTR caseExactSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.7 NAME 'umaccountlastaccesstime' DESC 'Last account access timestamp' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.8 NAME 'umivrgeneralmsgmailbox' DESC 'General message mailbox (default)' EQUALITY caseExactMatch SUBSTR caseExactSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.101 NAME 'umpinpwdcheckexpiration' DESC 'Whether to check pin/password expiration' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.102 NAME 'umpinpwdcheckrules' DESC 'Whether to check new pin/password rules violation' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.103 NAME 'umfmballowduplicatepin' DESC 'Allow duplicate password for sub mailboxes' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.131 NAME 'umenablevoicemail' DESC 'Voicemail features' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.132 NAME 'umenablefax' DESC 'Fax features' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.133 NAME 'umenablefaxautoprint' DESC 'Allow auto-forwarding faxes to umPrimaryFaxNumber' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.134 NAME 'umenableundeliverablenotification' DESC 'Allow notification of undeliverable messages' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.135 NAME 'umenabledeliveryconfirmation' DESC 'Allow delivery confirmation' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.136 NAME 'umenablecheckreceipt' DESC 'Allow checking message delivery to another subscriber' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.137 NAME 'umenableanonymousdelivery' DESC 'Allow marking messages anonymous' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.138 NAME 'umenableprivatedelivery' DESC 'Allow marking messages private' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.139 NAME 'umenableurgentdelivery' DESC 'Allow marking messages urgent' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.140 NAME 'umenableundeletemsgs' DESC 'Allow undelete messages' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.141 NAME 'umenableemail' DESC 'Allow listening to email messages' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.142 NAME 'umenableautoplayemail' DESC 'Allow automatic playing of email message body after envelope is played' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.143 NAME 'umenableemptycallcapture' DESC 'Enable the empty call capture feature so that subscriber can receive an empty message without body.' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.144 NAME 'umwebenablereplyvoicefax' DESC 'Enable replying to voice and fax messages from web' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.145 NAME 'umenablefuturedelivery' DESC 'Enable sending future delivery messages for (this is required in addition to mailfuturedeliveryenabled attribute)' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.146 NAME 'umenablevideo' DESC 'Video features' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.147 NAME 'umfmbchildattrlist' DESC 'List of attributes to be inherited from HOH to sub mailboxes' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.3.35.1.148 NAME 'umfmballowupdatebychild' DESC 'Allow interited attributes to be updated in sub mailboxes' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.149 NAME 'umivrenableavatarcontrol' DESC 'Allow system avatar control' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.150 NAME 'umivravatarprefs' DESC 'System avatar preference' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.3.35.1.151 NAME 'umivremaillangprefs' DESC 'Email language preference' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.161 NAME 'umsendvoicecontrol' DESC 'Voice message delivery control: A-all, F-family, S-system, 0-disabled' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,F,D,S,A' )",
   "( 1.3.6.1.4.1.2415.3.35.1.162 NAME 'umvoiceoutdialcontrol' DESC 'Voice outdial control: L-Local only, R-interRegion, I-International, 0-disabled' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,L,R,I' )",
   "( 1.3.6.1.4.1.2415.3.35.1.163 NAME 'umsendfaxcontrol' DESC 'Fax message delivery control: A-all, F-family, S-system, 0-disabled' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,F,S,A' )",
   "( 1.3.6.1.4.1.2415.3.35.1.164 NAME 'umfaxoutdialcontrol' DESC 'Fax outdial control: L-Local only, R-interRegion, I-International, 0-disabled' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,L,R,I' )",
   "( 1.3.6.1.4.1.2415.3.35.1.165 NAME 'ummessagedeliveryoptions' DESC 'Message delivery options: V-Voice Mail, M-Voice MMS, B-Both Voice Mail and Voice MMS' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,V,M,B' )",
   "( 1.3.6.1.4.1.2415.3.35.1.181 NAME 'ummaxphonenumbers' DESC 'Max number of account phone numbers including primary number' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.182 NAME 'ummaxfaxes' DESC 'Max number of fax messages' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.183 NAME 'ummaxfaxpages' DESC 'Max number of pages per fax message' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.191 NAME 'umvmmsdomain' DESC 'Domain name for Voice MMS message delivery' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.201 NAME 'umivrenableautologin' DESC 'Allow autologin' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.202 NAME 'umivrenablevolumecontrol' DESC 'Allow volume control' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.203 NAME 'umivrenablespeedcontrol' DESC 'Allow speed control' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.204 NAME 'umivrenabletutorial' DESC 'Allow play tutorial' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.205 NAME 'umivrenablenamegreeting' DESC 'Allow recorded name greeting' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.206 NAME 'umivrenablepersonalgreeting' DESC 'Allow recorded personal greeting' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.207 NAME 'umivrenablebusygreeting' DESC 'Allow recorded greeting to replace busy tone' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.208 NAME 'umivrenableskipusergreeting' DESC 'Allow skipping greeting and go directly to PIN prompt' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.209 NAME 'umivrenableskipcallergreeting' DESC 'Allow skipping greeting and go directly to recording prompt' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.210 NAME 'umivrenableusertransfer' DESC 'Allow transfering subscriber to operator' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.211 NAME 'umivrenablenestedvdls' DESC 'Allow nested voice distribution lists' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.212 NAME 'umivrenablescheduledgreetings' DESC 'Allow scheduled greetings' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.213 NAME 'umivrscheduledgreetingssettings' DESC 'Scheduled greetings settings' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.214 NAME 'umivrcalleridrestricted' DESC 'Whether messages are sent as anonymous: 0-disabled, 1-enabled' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.215 NAME 'umivroperatorschedulesettings' DESC 'A multi value attribute used in operator schedules' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.3.35.1.216 NAME 'umivrmaxcligreetings' DESC 'Max number of CLI greetings' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.217 NAME 'umivrcligreetingprefs' DESC 'CLI greeting preferences' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.3.35.1.231 NAME 'umivrcallertransfercontrol' DESC 'Inbound caller transfer to operator control: 0-disabled, T-transfer enabled, S-supervised transfer' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,S,T' )",
   "( 1.3.6.1.4.1.2415.3.35.1.232 NAME 'umivrautoplaycontrol' DESC 'What to do with messages after autoplay: 0-disabled, N-play and keep new, S-play and save' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,N,S' )",
   "( 1.3.6.1.4.1.2415.3.35.1.233 NAME 'umivrextendedabsencecontrol' DESC 'Extended absence greeting flow control: 0-Disabled, C-Disconnect, M-Allow Msg, T- Allow Transfer' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,C,M,T' )",
   "( 1.3.6.1.4.1.2415.3.35.1.234 NAME 'umivrmsgagingcontrol' DESC 'Options to aged messages: 0-disabled, S-resave after review, R-delete after review, W-delete with warning, D-delete' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,S,R,W,D' )",
   "( 1.3.6.1.4.1.2415.3.35.1.235 NAME 'umivrplaybackorder' DESC 'Playback order: D-default, F-FIFO, L-LIFO' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,D,F,L' )",
   "( 1.3.6.1.4.1.2415.3.35.1.236 NAME 'umivrpersonaloperatordefault' DESC 'How to select default value for personal operator: O-operator, P-user setting' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,O,P' )",
   "( 1.3.6.1.4.1.2415.3.35.1.251 NAME 'umivrmaxgreetingsecs' DESC 'Personal greeting max length in secs' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.252 NAME 'umivrmaxmsgsecs' DESC 'Single message max length in secs' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.253 NAME 'umivrmaxnewmsgdays' DESC 'Max number of days a new message can be stored' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.254 NAME 'umivrmaxsavedmsgdays' DESC 'Max number of days a saved message can be stored' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.255 NAME 'umivrmaxvdls' DESC 'Max number of voice distribution lists' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.256 NAME 'umivrmaxvdlentries' DESC 'Max number of entries in each voice distribution list' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.257 NAME 'umivrmaxvdlnamesecs' DESC 'Max duration of message for voice distribution list' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.258 NAME 'umivrmaxnamesecs' DESC 'Recorded name max length in secs' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.259 NAME 'umivrnumdigitsinextension' DESC 'Number of digits in extension' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.281 NAME 'umivrtutorialentryname' DESC 'Tutorial entry page name' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.301 NAME 'umivrskippin' DESC 'Skip pin at login; umIvrEnableAutoLogin has be to on' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.303 NAME 'umivrautoplay' DESC 'Allow bypassing all prompts and directly playing messages' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.304 NAME 'umivrplaytutorial' DESC 'Allow play tutorial at next login' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.305 NAME 'umivrplaydatetime' DESC 'Allow announcement of message timestamps' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.306 NAME 'umivrpromptlevel' DESC 'Menu prompt setting: S-standard, R-rapid, E-extended' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,S,R,E' )",
   "( 1.3.6.1.4.1.2415.3.35.1.307 NAME 'umivrcallerlocales' DESC 'List of languages picked by user for answering callers' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.308 NAME 'umivrflow' DESC 'Call flow name' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.309 NAME 'umivrgeneralgreetings' DESC 'Greetings configuration shared by all phones' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.310 NAME 'umivrvariant' DESC 'Variant name' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.311 NAME 'umivrtimeentryformat' DESC 'Time format used to exchange date/time information with the user, recognized formats are HHMM24, HHMM12' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.313 NAME 'umholidaylist' DESC 'List of holidays with format YYYY;MMDD,MMDD,MMDD...' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.3.35.1.314 NAME 'umserviceslist' DESC 'List of messaging services with format service-name;key=value,key=value' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.3.35.1.315 NAME 'umivrplaynameifavailable' DESC 'Allow announcement of sender name if it is recorded' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.316 NAME 'umivrfmfmmaxphonenumbers' DESC 'Max number of phone numbers used in find me follow me' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.317 NAME 'umivrfmfmphonenumber' DESC 'List of phone number in find me follow me in the format <ph num>;order=<index>;...' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.3.35.1.401 NAME 'umpn' DESC 'Phone number in canonical form cc.rc.line[-ext]' EQUALITY caseExactMatch SUBSTR caseExactSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.402 NAME 'umpntype' DESC 'Phone number type: M-mailbox, D-DTMF target, S-Special mailbox, E-Extension, F-forward target, K-pickup target, O-operator target, P-prompt target, W-wireless target' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,M,D,S,E,F,K,O,P,W' )",
   "( 1.3.6.1.4.1.2415.3.35.1.404 NAME 'umpnlabel' DESC 'Phone number related extra info for internal use' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.405 NAME 'umpngreetings' DESC 'Per phone greetings configuration for internal use' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.502 NAME 'umivrenablebusyrnaoption' DESC 'Allow busy or ring-no-answer options: 0-disabled, 1-enabled' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.503 NAME 'umivrenablecallermenu' DESC 'Allow caller menu: 0-disabled, 1-enabled' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.504 NAME 'umivrnumringsbeforetransfer' DESC 'Number of rings before a call is transfered' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,1-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.505 NAME 'umivrpoundkeycontrol' DESC 'Pound key behavior: S-subscriber access,  A-Administrator access, I-Ignore' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,S,A,I' )",
   "( 1.3.6.1.4.1.2415.3.35.1.506 NAME 'umivrstarkeycontrol' DESC 'Star key behavior: E-exit, I-ignore, M-mailbox, D-dial another phone number' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,E,I,M,D' )",
   "( 1.3.6.1.4.1.2415.3.35.1.507 NAME 'umivrstarkeymailbox' DESC 'Phone number for a mailbox accessed on start key input' EQUALITY caseExactMatch SUBSTR caseExactSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.508 NAME 'umivrecpmaxnoinput' DESC 'Max number of input attempts before a call is transfered to the operator' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.509 NAME 'umivrecpmaxnomatch' DESC 'Max number of invalid key entries allowed before a call is transfered to the operator' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.510 NAME 'umivrecpcallermenu' DESC 'Caller menu for internal use' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.511 NAME 'umivrcallforwardingmethod' DESC 'Call forwarding method for a special mailbox: T-transfer the call to specified destination, M-forward call directly to mailbox' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,T,M' )",
   "( 1.3.6.1.4.1.2415.3.35.1.512 NAME 'umivrextensiontype' DESC 'Mailbox extension type: D-DID, E-Extension' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,D,E' )",
   "( 1.3.6.1.4.1.2415.3.35.1.513 NAME 'umivrphoneextensionprefix' DESC 'Leading part of the phone number' EQUALITY caseExactMatch SUBSTR caseExactSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.514 NAME 'umivrspecialmailboxtype' DESC 'Special mailbox type in verbose form (e.g. ECP, TRANSFER, INFO)' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.602 NAME 'umivrenablephonelabels' DESC 'Allow labelling of phone numbers for multi-number account' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.700 NAME 'umdbnmaxnamestoprompt' DESC 'Maximum number of names to be prompted for Dial-By-Name' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,1-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.701 NAME 'umdbnmindigitstoenter' DESC 'Minimum number of digits required for Dial-By-Name' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,1-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.702 NAME 'umrealmlocale' DESC 'The default locale for the realm and the default language for voice prompts' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.703 NAME 'umuserlocalelist' DESC 'The list of languages from which a subscriber can specify languages used for mailbox prompts' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.704 NAME 'umcallerlocalelist' DESC 'The list of languages from which a subscriber can specify languages used to answer calls' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.705 NAME 'umemaillocalelist' DESC 'The list of languages from which a subscriber can specify TTS language to play back emails' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.706 NAME 'umdbnkeypad' DESC 'The Dial-By-Name keypad used in a domain' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.707 NAME 'umdbnnameorder' DESC 'The Dial-By-Name name order such as whether to put first name first' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.800 NAME 'umenableautoprovisioning' DESC 'Allow auto-provisioning of accounts directly under an entry' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.801 NAME 'umautoprovisioningkeys' DESC 'Specific keys used to select an entry to auto-provision accounts under' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.3.35.1.802 NAME 'umautoprovisioningminkey' DESC 'Key used to select an entry to auto-provision accounts under must be greater than or equal to this' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.803 NAME 'umautoprovisioningmaxkey' DESC 'Key used to select an entry to auto-provision accounts under must be less than or equal to this' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.804 NAME 'umautoprovisioningadminpolicydn' DESC 'The admin policy DN to assign to an auto-provisioned account' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.805 NAME 'umautoprovisioningmaildomain' DESC 'The mail domain to assign to an auto-provisioned account' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.806 NAME 'umautoprovisioningmaillogin' DESC 'The format of the mail login to assign to an auto-provisioned account' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.807 NAME 'umautoprovisioningmailprefix' DESC 'The format of the mail prefix to assign to an auto-provisioned account' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.808 NAME 'umautoprovisioningmss' DESC 'The message store instance to assign to an auto-provisioned account' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.809 NAME 'umautoprovisioningpassword' DESC 'The password to assign to an auto-provisioned account' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.810 NAME 'umautoprovisioningpin' DESC 'Maximum number used to select an entry to auto-provision accounts under' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.811 NAME 'umautoprovisioningtargetnumberallowlist' DESC 'List of canonicalized target numbers for which auto-provisioning is allowed if prompt target is called' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36 )",
   "( 1.3.6.1.4.1.2415.3.35.1.812 NAME 'umautoprovisioningnotifytypes' DESC 'The notification types to assign to an auto-provisioned account' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.774.767.1.4 NAME 'notifybulkemail' DESC 'Account used for Information Provider bulk email' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.5 NAME 'notifydeleteemail' DESC 'Delete email message after notification sent' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.55 NAME 'notifybillingtype' DESC 'Site specific billing type' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.58 NAME 'notifyservicelist' DESC 'List of services permitted for use by all users in the admin policy; should not be overridden in the person entry; format: value = on or value = off' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.774.767.1.74 NAME 'notifyserviceoverride' DESC 'List of services enabled by a particular user; should only be set in the person entry and not the admin policy; format: value = on or value = off' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.774.767.1.8 NAME 'notifyfiltperuser' DESC 'User allowed to modify notification filters' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.10 NAME 'notifyfiltrulename' DESC 'Notification filter rule name' SUP name SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.12 NAME 'notifyfiltrulevalue' DESC 'Notification filter rule value' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.13 NAME 'notifyfiltdefaultaction' DESC 'Default action for notification' EQUALITY caseIgnoreIA5Match SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.59 NAME 'notifyfiltactive' DESC 'Boolean indicating whether filter is active or not' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.60 NAME 'notifyfiltprofile' DESC 'Name of the profile associated with the rule' SUP name SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.61 NAME 'notifyfiltruleservice' DESC 'Notification filter rule service' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.62 NAME 'notifyfiltruleeventlist' DESC 'List of event types' EQUALITY caseIgnoreIA5Match SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 )",
   "( 1.3.6.1.4.1.2415.774.767.1.63 NAME 'notifyfiltrulelanguage' DESC 'Notification filter rule language' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.64 NAME 'notifyfiltrulescope' DESC 'Notification filter rule type' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,global,cos,shared,subscriber' )",
   "( 1.3.6.1.4.1.2415.774.767.1.65 NAME 'notifyfiltshareddn' DESC 'A dn referencing a shared filter rule' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.66 NAME 'notifyrulesetname' DESC 'Name of the rule set, either format or filter' SUP name SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.76 NAME 'notifyattributelist' DESC 'List of attribute names owned by a service' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.774.767.1.50 NAME 'notifyfmtruleid' DESC 'Notification Fmt Rule Id' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.17 NAME 'notifyfmtrulename' DESC 'Notification format rule name' SUP name SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.18 NAME 'notifyfmtruletype' DESC 'Notification format rule type - SOM, EOM, etc.' SUP name SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.19 NAME 'notifyfmtrulevalue' DESC 'Notification format rule value' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.26 NAME 'notifyfmtattchnone' DESC 'Display zero if no attachments' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.67 NAME 'notifyfmtrulelocale' DESC 'Locale for this format rule value' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.68 NAME 'notifyfmtrulegroupname' DESC 'Notification format rule group name' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.69 NAME 'notifyfmtrulegrouptype' DESC ' Notification format rule group type default, cos' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.70 NAME 'notifyfmtrulegroupservice' DESC 'Service associated with this format rule (e.g. Calendar)' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.71 NAME 'notifyfmtrulegroupntfntype' DESC 'Notification type associated with this format rule (e.g. SMPP, SMTP)' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.72 NAME 'notifyfmtrulegroupeventtype' DESC 'Event Type associated with this format rule (e.g. NEWU, APPT)' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.73 NAME 'notifyfmtrulegroupdlvtype' DESC 'Delivery type for this format rule (e.g. SMDI, SMPPMWI, ICQ)' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.75 NAME 'notifyfmtrulegroupbasedn' DESC 'DN of format rule groups location' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.774.767.1.30 NAME 'smsmin' DESC 'Mobile ID' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.8.1.2 NAME 'netmailautocollect' DESC 'List of email address to collect from an outgoing email' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,all,to,none' )",
   "( 1.3.6.1.4.1.2415.8.1.5 NAME 'netmailmsgsperpage' DESC 'Number of messages displayed per page' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.8.1.6 NAME 'netmailreplyformat' DESC 'Default reply separator 0-line, 1-character, 2-none' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1,2' )",
   "( 1.3.6.1.4.1.2415.8.1.11 NAME 'netmaildefaulteditor' DESC 'Use plain text or HTML editor by default 0-Plain text, 1-HTML' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.8.1.12 NAME 'netmailmsglistcols' DESC 'Columns displayed in the message entries list' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.8.1.13 NAME 'netmailautopopemail' DESC 'External mail is retrieved at login, automatically or manually 0-manual, 1-login, 2-automatic' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1,2' )",
   "( 1.3.6.1.4.1.2415.8.1.14 NAME 'netmailpopemailacctselect' DESC 'If account is POPed 0-individual, 1-all' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.8.1.16 NAME 'netmailactivealias' DESC 'Active alias' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.8.1.17 NAME 'netmailpopacctdetails' DESC 'Pop account details (SMTP address, Destination Folder, Delete Message Flag, From Name, User Name, Password, Pop Server Name, Pop Server Port, Timeout, UID List, Icon Type, Password encryption type) per account' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.8.1.18 NAME 'netmailabentriesperpage' DESC 'Number of address book entries to display on a web page' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.8.1.21 NAME 'netmailenablevoice' DESC 'If account can view voicemail 0-no, 1-yes' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.8.1.22 NAME 'netmailenablefax' DESC 'If account can view fax 0-no, 1-yes' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.8.1.24 NAME 'netmailcurrentver' DESC 'Indicates WebEdge Version user data is set up for' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.8.30.1.1 NAME 'netmailsendreturnreceipt' DESC 'Indicates return-receipt procedure' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,always,never,ask' )",
   "( 1.3.6.1.4.1.2415.8.30.1.3 NAME 'netmobilemailabsortby' DESC 'Contact field to sort the address book entries on a WAP page' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.8.30.1.4 NAME 'netmobilemailabdisplayby' DESC 'Contact field to display contacts on a WAP page' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.8.30.1.19 NAME 'netmailaddressbookcontactlistmax' DESC 'Maximum number of contact lists in a users address book' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.8.30.1.44 NAME 'netmailmsgviewprivacyfilter' DESC 'Determines whether HTML content in recieved messages is filtered when viewed in Webedge' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.8.30.1.45 NAME 'netmailrequestreturnreceipt' DESC 'Automatically send return receipt requests with outgoing messages? 0-no, 1-yes' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.8.30.1.46 NAME 'netmailautospellcheck' DESC 'Automatically spell check when sending messages? 0-no, 1-yes' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.8.30.1.14 NAME 'buddyname' SUP name )",
   "( 1.3.6.1.4.1.2415.8.30.1.15 NAME 'improvider' SUP name )",
   "( 1.3.6.1.4.1.2415.8.30.1.18 NAME 'mailwebmailchangepassword' DESC 'Is a self care user allowed to change their password 0-No, 1-Yes' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.8.30.1.5 NAME 'adminfamilymaxusers' EQUALITY integermatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.8.30.1.6 NAME 'adminfamilymaxstoragekb' EQUALITY integermatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.8.30.1.16 NAME 'adminrealmspecdn' DESC 'Indicates type of adminrealm' EQUALITY distinguishedNameMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.9 NAME 'umivraccesslastlocktime' DESC 'Subscribers last TUI access lock timestamp' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.708 NAME 'umivraccesslockperiod' DESC 'The amount of time a subscriber TUI access should be locked in seconds' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,-1-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.403 NAME 'umpnstatus' DESC 'Phone number status: A-Active, S-Suspended, L-Locked' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,A,S,L' )",
   "( 1.3.6.1.4.1.2415.8.30.1.48 NAME 'netmailusetrash' DESC 'Move to Trash when deleting messages? 0-no, 1-yes' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.8.30.1.49 NAME 'netmailsignaturebeforereply' DESC 'Place signature before reply? 0-after, 1-before' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.312 NAME 'umaddonservicelist' DESC 'Generic attribute to represent additional services (customization)' EQUALITY caseIgnoreMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.3.35.1.104 NAME 'umpinmaxlength' DESC 'Max number of digits allowed in pin' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.105 NAME 'umpinminlength' DESC 'Min number of digits allowed in pin' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.106 NAME 'umpinpwdrules' DESC 'Pin/password Rules' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.3.35.1.107 NAME 'umpinpwdlifetimedays' DESC 'Lifetime of pin/password in days' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.406 NAME 'umpnlocale' DESC 'Per phone locale' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.351 NAME 'umivrtriggerapps' DESC 'Application Server Trigger Mappings' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.3.35.1.352 NAME 'umivrtriggerappsdefault' DESC 'Application Server Default Trigger Mappings' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.3.35.1.361 NAME 'umivrmaxringbacktones' DESC 'Max number of ringback tones' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.362 NAME 'umivrringbacktoneprefs' DESC 'Ringback tone prefs: 0-feature turned off, 1-feature turned on' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.363 NAME 'umivrdefaultringbacktone' DESC 'default ringback tone' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.364 NAME 'umivravailringbacktones' DESC 'available ringback tone clips' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.3.35.1.365 NAME 'umivrmaxcelebgreetings' DESC 'Max number of celebrity greetings' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.366 NAME 'umivrcelebgreetingprefs' DESC 'Celebrity greeting prefs: 0-feature turned off, 1-feature turned on' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.367 NAME 'umivrdefaultcelebgreeting' DESC 'default celebrity greeting' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.368 NAME 'umivravailcelebgreetings' DESC 'available celebrity greetings' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.7.55.1.11 NAME 'transactid' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.7.55.1.12 NAME 'createhost' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 )",
   "( 1.3.6.1.4.1.2415.7.55.1.13 NAME 'masterserverrole' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.7.55.1.14 NAME 'metavalue' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.2.2.1.89 NAME 'targetobjectclass' EQUALITY objectIdentifierMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.38 )",
   "( 1.3.6.1.4.1.2415.2.2.1.143 NAME 'listheaderstoberemoved' EQUALITY caseIgnoreIA5Match ORDERING caseIgnoreIA5OrderingMatch SUBSTR caseIgnoreIA5SubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 )",
   "( 1.3.6.1.4.1.2415.2.52.1.10 NAME 'mailpopunifyenabled' DESC 'Determines whether if the mailbox uses the unify mode in POP sessions.' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.2.52.1.11 NAME 'mailpopunifyhost' DESC 'Specifies the POP server host name for the old system unified POP sessions.' EQUALITY caseIgnoreIA5Match ORDERING caseIgnoreIA5OrderingMatch SUBSTR caseIgnoreIA5SubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{255}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.105 NAME 'mailblocksenderspabaccess' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.2.60.1.106 NAME 'mailblocksenderspabactive' EQUALITY integerMatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.318 NAME 'umservicecontrollist' DESC 'Generic attribute for controlling services at class of service level' SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.3.35.1.407 NAME 'umid' DESC 'Text user id' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.709 NAME 'umoffsystemdeliveryoption' DESC 'Off system message delivery option: V-vpim, O-outdial' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,V,O' )",
   "( 1.3.6.1.4.1.2415.3.35.1.820 NAME 'umaggregatentfnprofile' DESC 'User profile to determine type of aggregated notification to send in SMS replace-if-present: L-low end, H-high end' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,L,H' )",
   "( 1.3.6.1.4.1.2415.3.35.1.821 NAME 'umntfnerroraction' DESC 'Action(s) to be taken when an error is encountered on notification' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.3.35.1.822 NAME 'umntfnretrycriteria' DESC 'Specification of the number of notification retries and retry intervals for various error cases for a particular delivery type' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.3.35.1.840 NAME 'umabentryid' DESC 'Unique ID of an addressbook entry' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.7.55.1.236 NAME 'updateintervalas100millisecs' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-1' )",
   "( 1.3.6.1.4.1.2415.7.55.1.237 NAME 'acigeneralrule' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 USAGE dSAOperation )",
   "( 1.3.6.1.4.1.2415.7.55.1.238 NAME 'acigeneralruleexception' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 USAGE dSAOperation )",
   "( 1.3.6.1.4.1.1466.101.120.16 NAME 'cacheable' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 USAGE directoryOperation )",
   "( 1.3.6.1.4.1.2415.2.60.1.107 NAME 'vmsspoplogin' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15{129}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.108 NAME 'vmsspoppassword' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15{64}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.109 NAME 'vmsspophost' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.110 NAME 'vmsssmtpaddress' EQUALITY caseIgnoreIA5Match ORDERING caseIgnoreIA5OrderingMatch SUBSTR caseIgnoreIA5SubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26{256}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.111 NAME 'vmsssmtphost' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.120 NAME 'vmssimaplogin' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15{129}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.121 NAME 'vmssimappassword' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15{64}  SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.122 NAME 'vmssimaphost' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.123 NAME 'vmsspopunregistered' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.124 NAME 'vmssimapunregistered' EQUALITY booleanMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.125 NAME 'vmssextmbox' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.2.2.1.18 NAME 'scattributeindexinfo' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.40 USAGE directoryOperation )",
   "( 1.3.6.1.4.1.2415.2.60.1.126 NAME 'mailindexhost' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.127 NAME 'mailsearchhost' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.60.1.115 NAME 'mailsmtpenforcefrom' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,default,all,header,envelope,none' )",
   "( 1.3.6.1.4.1.2415.3.35.1.320 NAME 'umivrplayonlymsghdrs' DESC 'Allow to play only message headers during message playback' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.321 NAME 'umivrplayaniifavailable' DESC 'Allow to play phone number during message playback' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.369 NAME 'umivrmaxcelebcligreetings' DESC 'Max number of caller specific celebrity greetings' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2147483647' )",
   "( 1.3.6.1.4.1.2415.3.35.1.10 NAME 'umsecondaryfaxnumber' DESC 'Secondary fax number to print to' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.319 NAME 'umivrenableplaycallbacknumber' DESC 'Allow to play the call back number before playing message' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.166 NAME 'umdestoutdialcontrol' DESC 'Destination outdial control: S-Source, D-Destination, K-Key, 0-disabled' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,S,D,K' )",
   "( 1.3.6.1.4.1.2415.3.35.1.302 NAME 'umivrautoprint' DESC 'Inbound fax auto-print enabled' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1,2' )",
   "( 1.3.6.1.4.1.2415.3.35.1.601 NAME 'umdestsearchparam' DESC 'Key for destination parameters search criteria' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.370 NAME 'umivrenablecelebgreetings' DESC 'Provision celebrity greetings: 0-feature turned off, 1-feature turned on' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.371 NAME 'umivrenableringbacktones' DESC 'Provision ringback tones: 0-feature turned off, 1-feature turned on' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.219 NAME 'umivrnonsubscribernameprefs' DESC 'non-subcriber number to greeting gid mapping' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.3.35.1.322 NAME 'umivrallowadminaccess' DESC 'Allow admin access: N-no access, L-limited access, F-Full access' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,N,L,F' )",
   "( 1.3.6.1.4.1.2415.3.35.1.323 NAME 'umivrenableadmincommercialtransfer' DESC 'Enable admin commercial transfer' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.515 NAME 'umivrholidaygreetcontrol' DESC 'Controls availability of holiday greeting feature in AA mailbox' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.516 NAME 'umivrweekendgreetcontrol' DESC 'Controls availability of weekend greeting feature in AA mailbox' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.517 NAME 'umivrafterhoursgreetcontrol' DESC 'Controls availability of After Hours greeting feature in AA mailbox' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.260 NAME 'umivrmaxcaptionsecs' DESC 'Single caption max length in secs' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.325 NAME 'umivrenablebbmailbox' DESC 'Enable BB mailbox' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.170 NAME 'umivrenableasr' DESC 'Enable ASR functionality' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.218 NAME 'umivrenablevdlcligreetings' DESC 'Enable CLI greetings for VDLs: 0-disabled, 1-enabled' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.518 NAME 'ummediaonholdsource' DESC 'URL for subscriber-specific Media-On-Hold media' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.841 NAME 'umenablecommercialgdluserprefs' DESC 'Allow commercial GDL usage: 0-disabled, 1-enabled' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.842 NAME 'umivrenablebroadcastuserprefs' DESC 'Broadcast feature at user level 0=Feature turned OFF, 1=Feature turned ON' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.844 NAME 'umenablebroadcast' DESC 'Broadcast feature at COS level 0=Feature turned OFF, 1=Feature turned ON' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.845 NAME 'umivrenablespeechtotext' DESC 'Provision TUI for speech-to-text feature 0=TUI turned OFF, 1=TUI turned ON' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.846 NAME 'umenablespeechtotext' DESC 'Enable/disable speech-to-text feature 0=Feature turned OFF, 1=Feature turned ON' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.847 NAME 'umspeechtotextprioritysettings' DESC 'Subscriber preference speech to text, priority settings 0=Speech to text for ALL voice messages, 1=Speech to text for URGENT voice messages only' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.2.79.1.0 NAME 'mailpopunifylogin' DESC 'Specifies the remote POP server login name in unified POP sessions.' EQUALITY caseIgnoreMatch ORDERING caseIgnoreOrderingMatch SUBSTR caseIgnoreSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.79.1.1 NAME 'mailpopunifypassword' DESC 'Specifies the remote POP server password in unified POP sessions.' EQUALITY caseExactMatch ORDERING caseExactOrderingMatch SUBSTR caseExactSubstringsMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.2.2.1.206 NAME 'mailfolderquota' DESC 'One string with varying quotas for each of the users folders.' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15{4000}  )",
   "( 1.3.6.1.4.1.2415.2.2.1.37 NAME 'mailquotatotkb' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2097151' )",
   "( 1.3.6.1.4.1.2415.2.2.1.38 NAME 'mailquotamaxmsgkb' EQUALITY integermatch ORDERING integerOrderingMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2097151' )",
   "( 1.3.6.1.4.1.2415.2.52.1.1 NAME 'mailquotasendermaxmsgkb' EQUALITY integerMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE X-VALUE-CONSTRAINT 'RANGE,0-2097151' )",
   "( 1.3.6.1.4.1.2415.3.35.1.324 NAME 'umivrusertype' DESC 'User Type: A-admin-commercial S-subscriber-commercial O-other' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,A,S,O,P' )",
   "( 1.3.6.1.4.1.2415.3.35.1.501 NAME 'umivrcallerinputtype' DESC 'Caller input type: N-name, E-extension, M-mailbox, I-ignore, V-name with asr,D-department list' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.44{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,N,E,M,I,A,V,D' )",
   "( 1.3.6.1.4.1.2415.3.35.1.848 NAME 'umivrenablelistenin' DESC 'Subscriber preference listen-in feature, 0=Feature turned OFF, 1=Feature turned ON' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.849 NAME 'umivrlistenintriggernumbers' DESC 'reason code to number mapping' EQUALITY caseExactMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 1.3.6.1.4.1.2415.3.35.1.850 NAME 'umivrenablelivereplyconf' DESC 'Subscriber preference live-reply conference feature, 0=Feature turned OFF, 1=Feature turned ON' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.851 NAME 'umivrconfmediaonhold' DESC 'subscriber specific conference hold media' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.852 NAME 'umspeechtotexttranscriptionsettings' DESC 'Control speech-to-text transcription delivery 0=ALL messages, 1=NEW messages only' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.853 NAME 'umivrenableexchangetts' DESC 'Allow exchange TTS access feature to COS, 0=Feature turned OFF, 1=Feature turned ON' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.854 NAME 'umenableexchangetts' DESC 'Allow Subscriber exchange TTS access feature to COS, 0=Feature turned OFF, 1=Feature turned ON' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.855 NAME 'umexchangeserveraddress' DESC 'FQDN or IP address of MS Exchange server of a subscriber' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.856 NAME 'umexchangeserverusername' DESC 'Subscriber Username to access MS Exchange server account' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.857 NAME 'umexchangeserveruserpassword' DESC 'Subscriber Password to access MS Exchange server account' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.858 NAME 'umivrenablereminderuserprefs' DESC 'Reminder feature at user level 0=Feature turned OFF, 1=Feature turned ON' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.859 NAME 'umenablereminder' DESC 'Reminder feature at COS level 0=Feature turned OFF, 1=Feature turned ON' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.860 NAME 'umenablecontentsearch' DESC 'Content feature at COS level 0=Feature turned OFF, 1=Feature turned ON' EQUALITY numericStringMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.36{1}  SINGLE-VALUE X-VALUE-CONSTRAINT 'CHOICE,0,1' )",
   "( 1.3.6.1.4.1.2415.3.35.1.861 NAME 'addressbookprovider' DESC 'Nab type' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.862 NAME 'umnabusername' DESC 'Subscriber username to access network address book' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )",
   "( 1.3.6.1.4.1.2415.3.35.1.863 NAME 'umnabpassword' DESC 'Subscriber password to access network address book' EQUALITY caseIgnoreMatch SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 SINGLE-VALUE )"],
 "matchingRules"=>
  ["( 1.3.6.1.4.1.2415.2.3.3.1    NAME 'caseExactIA5OrderingMatch'   DESC 'SWCM defined OID for caseExactIA5OrderingMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 )",
   "( 1.3.6.1.4.1.2415.2.3.3.2    NAME 'caseIgnoreIA5OrderingMatch'   DESC 'SWCM defined OID for caseIgnoreIA5OrderingMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 )",
   "( 1.3.6.1.4.1.2415.2.3.3.3    NAME 'distinguishedNameSubstringMatch'   DESC 'OPWV defined matching rule to do substring comparison of DNs'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 )",
   "( 2.5.13.16   NAME 'bitStringMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.6 )",
   "( 2.5.13.13   NAME 'booleanMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.7 )",
   "( 2.5.13.5   NAME 'caseExactMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 2.5.13.6   NAME 'caseExactOrderingMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 2.5.13.7   NAME 'caseExactSubstringsMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.58 )",
   "( 2.5.13.2   NAME 'caseIgnoreMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 2.5.13.3   NAME 'caseIgnoreOrderingMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.15 )",
   "( 2.5.13.4   NAME 'caseIgnoreSubstringsMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.58 )",
   "( 2.5.13.11   NAME 'caseIgnoreListMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.41 )",
   "( 1.3.6.1.4.1.1466.109.114.1   NAME 'caseExactIA5Match'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 )",
   "( 1.3.6.1.4.1.4203.1.2.1   NAME 'caseExactIA5SubstringsMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.58 )",
   "( 1.3.6.1.4.1.1466.109.114.2   NAME 'caseIgnoreIA5Match'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.26 )",
   "( 1.3.6.1.4.1.1466.109.114.3   NAME 'caseIgnoreIA5SubstringsMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.58 )",
   "( 2.5.13.1   NAME 'distinguishedNameMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.12 )",
   "( 2.5.13.14   NAME 'integerMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 )",
   "( 2.5.13.15   NAME 'integerOrderingMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 )",
   "( 2.5.13.27   NAME 'generalizedTimeMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.24 )",
   "( 2.5.13.28   NAME 'generalizedTimeOrderingMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.24 )",
   "( 2.5.13.8   NAME 'numericStringMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.36 )",
   "( 2.5.13.9   NAME 'numericStringOrderingMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.36 )",
   "( 2.5.13.10   NAME 'numericStringSubstringsMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.58 )",
   "( 2.5.13.0   NAME 'objectIdentifierMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.38 )",
   "( 2.5.13.17   NAME 'octetStringMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.40 )",
   "( 2.5.13.18   NAME 'octetStringOrderingMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.40 )",
   "( 2.5.13.20   NAME 'telephoneNumberMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.50 )",
   "( 2.5.13.21   NAME 'telephoneNumberSubstringsMatch'   SYNTAX 1.3.6.1.4.1.1466.115.121.1.50 )"]}
